class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QGL():
    """"""
    # Enum QGL.FormatOption
    DoubleBuffer = 0
    DepthBuffer = 0
    Rgba = 0
    AlphaChannel = 0
    AccumBuffer = 0
    StencilBuffer = 0
    StereoBuffers = 0
    DirectRendering = 0
    HasOverlay = 0
    SampleBuffers = 0
    SingleBuffer = 0
    NoDepthBuffer = 0
    ColorIndex = 0
    NoAlphaChannel = 0
    NoAccumBuffer = 0
    NoStencilBuffer = 0
    NoStereoBuffers = 0
    IndirectRendering = 0
    NoOverlay = 0
    NoSampleBuffers = 0
    DeprecatedFunctions = 0
    NoDeprecatedFunctions = 0

    def setPreferredPaintEngine(self, engineType):
        '''static void QGL.setPreferredPaintEngine(QPaintEngine.Type engineType)'''
    class FormatOptions():
        """"""
        def __init__(self):
            '''QGL.FormatOptions QGL.FormatOptions.__init__()'''
            return QGL.FormatOptions()
        def __init__(self):
            '''int QGL.FormatOptions.__init__()'''
            return int()
        def __init__(self):
            '''void QGL.FormatOptions.__init__()'''
        def __bool__(self):
            '''int QGL.FormatOptions.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QGL.FormatOptions.__ne__(QGL.FormatOptions f)'''
            return bool()
        def __eq__(self, f):
            '''bool QGL.FormatOptions.__eq__(QGL.FormatOptions f)'''
            return bool()
        def __invert__(self):
            '''QGL.FormatOptions QGL.FormatOptions.__invert__()'''
            return QGL.FormatOptions()
        def __and__(self, mask):
            '''QGL.FormatOptions QGL.FormatOptions.__and__(int mask)'''
            return QGL.FormatOptions()
        def __xor__(self, f):
            '''QGL.FormatOptions QGL.FormatOptions.__xor__(QGL.FormatOptions f)'''
            return QGL.FormatOptions()
        def __xor__(self, f):
            '''QGL.FormatOptions QGL.FormatOptions.__xor__(int f)'''
            return QGL.FormatOptions()
        def __or__(self, f):
            '''QGL.FormatOptions QGL.FormatOptions.__or__(QGL.FormatOptions f)'''
            return QGL.FormatOptions()
        def __or__(self, f):
            '''QGL.FormatOptions QGL.FormatOptions.__or__(int f)'''
            return QGL.FormatOptions()
        def __int__(self):
            '''int QGL.FormatOptions.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QGL.FormatOptions QGL.FormatOptions.__ixor__(QGL.FormatOptions f)'''
            return QGL.FormatOptions()
        def __ior__(self, f):
            '''QGL.FormatOptions QGL.FormatOptions.__ior__(QGL.FormatOptions f)'''
            return QGL.FormatOptions()
        def __iand__(self, mask):
            '''QGL.FormatOptions QGL.FormatOptions.__iand__(int mask)'''
            return QGL.FormatOptions()


class QGLFormat():
    """"""
    # Enum QGLFormat.OpenGLContextProfile
    NoProfile = 0
    CoreProfile = 0
    CompatibilityProfile = 0

    # Enum QGLFormat.OpenGLVersionFlag
    OpenGL_Version_None = 0
    OpenGL_Version_1_1 = 0
    OpenGL_Version_1_2 = 0
    OpenGL_Version_1_3 = 0
    OpenGL_Version_1_4 = 0
    OpenGL_Version_1_5 = 0
    OpenGL_Version_2_0 = 0
    OpenGL_Version_2_1 = 0
    OpenGL_Version_3_0 = 0
    OpenGL_Version_3_1 = 0
    OpenGL_Version_3_2 = 0
    OpenGL_Version_3_3 = 0
    OpenGL_Version_4_0 = 0
    OpenGL_ES_Common_Version_1_0 = 0
    OpenGL_ES_CommonLite_Version_1_0 = 0
    OpenGL_ES_Common_Version_1_1 = 0
    OpenGL_ES_CommonLite_Version_1_1 = 0
    OpenGL_ES_Version_2_0 = 0

    def __init__(self):
        '''void QGLFormat.__init__()'''
    def __init__(self, options, plane = 0):
        '''void QGLFormat.__init__(QGL.FormatOptions options, int plane = 0)'''
    def __init__(self, other):
        '''void QGLFormat.__init__(QGLFormat other)'''
    def __eq__(self):
        '''QGLFormat QGLFormat.__eq__()'''
        return QGLFormat()
    def __ne__(self):
        '''QGLFormat QGLFormat.__ne__()'''
        return QGLFormat()
    def profile(self):
        '''QGLFormat.OpenGLContextProfile QGLFormat.profile()'''
        return QGLFormat.OpenGLContextProfile()
    def setProfile(self, profile):
        '''void QGLFormat.setProfile(QGLFormat.OpenGLContextProfile profile)'''
    def minorVersion(self):
        '''int QGLFormat.minorVersion()'''
        return int()
    def majorVersion(self):
        '''int QGLFormat.majorVersion()'''
        return int()
    def setVersion(self, major, minor):
        '''void QGLFormat.setVersion(int major, int minor)'''
    def openGLVersionFlags(self):
        '''static QGLFormat.OpenGLVersionFlags QGLFormat.openGLVersionFlags()'''
        return QGLFormat.OpenGLVersionFlags()
    def swapInterval(self):
        '''int QGLFormat.swapInterval()'''
        return int()
    def setSwapInterval(self, interval):
        '''void QGLFormat.setSwapInterval(int interval)'''
    def blueBufferSize(self):
        '''int QGLFormat.blueBufferSize()'''
        return int()
    def setBlueBufferSize(self, size):
        '''void QGLFormat.setBlueBufferSize(int size)'''
    def greenBufferSize(self):
        '''int QGLFormat.greenBufferSize()'''
        return int()
    def setGreenBufferSize(self, size):
        '''void QGLFormat.setGreenBufferSize(int size)'''
    def redBufferSize(self):
        '''int QGLFormat.redBufferSize()'''
        return int()
    def setRedBufferSize(self, size):
        '''void QGLFormat.setRedBufferSize(int size)'''
    def sampleBuffers(self):
        '''bool QGLFormat.sampleBuffers()'''
        return bool()
    def hasOverlay(self):
        '''bool QGLFormat.hasOverlay()'''
        return bool()
    def directRendering(self):
        '''bool QGLFormat.directRendering()'''
        return bool()
    def stereo(self):
        '''bool QGLFormat.stereo()'''
        return bool()
    def stencil(self):
        '''bool QGLFormat.stencil()'''
        return bool()
    def accum(self):
        '''bool QGLFormat.accum()'''
        return bool()
    def alpha(self):
        '''bool QGLFormat.alpha()'''
        return bool()
    def rgba(self):
        '''bool QGLFormat.rgba()'''
        return bool()
    def depth(self):
        '''bool QGLFormat.depth()'''
        return bool()
    def doubleBuffer(self):
        '''bool QGLFormat.doubleBuffer()'''
        return bool()
    def hasOpenGLOverlays(self):
        '''static bool QGLFormat.hasOpenGLOverlays()'''
        return bool()
    def hasOpenGL(self):
        '''static bool QGLFormat.hasOpenGL()'''
        return bool()
    def setDefaultOverlayFormat(self, f):
        '''static void QGLFormat.setDefaultOverlayFormat(QGLFormat f)'''
    def defaultOverlayFormat(self):
        '''static QGLFormat QGLFormat.defaultOverlayFormat()'''
        return QGLFormat()
    def setDefaultFormat(self, f):
        '''static void QGLFormat.setDefaultFormat(QGLFormat f)'''
    def defaultFormat(self):
        '''static QGLFormat QGLFormat.defaultFormat()'''
        return QGLFormat()
    def testOption(self, opt):
        '''bool QGLFormat.testOption(QGL.FormatOptions opt)'''
        return bool()
    def setOption(self, opt):
        '''void QGLFormat.setOption(QGL.FormatOptions opt)'''
    def setPlane(self, plane):
        '''void QGLFormat.setPlane(int plane)'''
    def plane(self):
        '''int QGLFormat.plane()'''
        return int()
    def setOverlay(self, enable):
        '''void QGLFormat.setOverlay(bool enable)'''
    def setDirectRendering(self, enable):
        '''void QGLFormat.setDirectRendering(bool enable)'''
    def setStereo(self, enable):
        '''void QGLFormat.setStereo(bool enable)'''
    def setStencil(self, enable):
        '''void QGLFormat.setStencil(bool enable)'''
    def setAccum(self, enable):
        '''void QGLFormat.setAccum(bool enable)'''
    def setAlpha(self, enable):
        '''void QGLFormat.setAlpha(bool enable)'''
    def setRgba(self, enable):
        '''void QGLFormat.setRgba(bool enable)'''
    def setDepth(self, enable):
        '''void QGLFormat.setDepth(bool enable)'''
    def setDoubleBuffer(self, enable):
        '''void QGLFormat.setDoubleBuffer(bool enable)'''
    def samples(self):
        '''int QGLFormat.samples()'''
        return int()
    def setSamples(self, numSamples):
        '''void QGLFormat.setSamples(int numSamples)'''
    def setSampleBuffers(self, enable):
        '''void QGLFormat.setSampleBuffers(bool enable)'''
    def stencilBufferSize(self):
        '''int QGLFormat.stencilBufferSize()'''
        return int()
    def setStencilBufferSize(self, size):
        '''void QGLFormat.setStencilBufferSize(int size)'''
    def alphaBufferSize(self):
        '''int QGLFormat.alphaBufferSize()'''
        return int()
    def setAlphaBufferSize(self, size):
        '''void QGLFormat.setAlphaBufferSize(int size)'''
    def accumBufferSize(self):
        '''int QGLFormat.accumBufferSize()'''
        return int()
    def setAccumBufferSize(self, size):
        '''void QGLFormat.setAccumBufferSize(int size)'''
    def depthBufferSize(self):
        '''int QGLFormat.depthBufferSize()'''
        return int()
    def setDepthBufferSize(self, size):
        '''void QGLFormat.setDepthBufferSize(int size)'''
    class OpenGLVersionFlags():
        """"""
        def __init__(self):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__init__()'''
            return QGLFormat.OpenGLVersionFlags()
        def __init__(self):
            '''int QGLFormat.OpenGLVersionFlags.__init__()'''
            return int()
        def __init__(self):
            '''void QGLFormat.OpenGLVersionFlags.__init__()'''
        def __bool__(self):
            '''int QGLFormat.OpenGLVersionFlags.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QGLFormat.OpenGLVersionFlags.__ne__(QGLFormat.OpenGLVersionFlags f)'''
            return bool()
        def __eq__(self, f):
            '''bool QGLFormat.OpenGLVersionFlags.__eq__(QGLFormat.OpenGLVersionFlags f)'''
            return bool()
        def __invert__(self):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__invert__()'''
            return QGLFormat.OpenGLVersionFlags()
        def __and__(self, mask):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__and__(int mask)'''
            return QGLFormat.OpenGLVersionFlags()
        def __xor__(self, f):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__xor__(QGLFormat.OpenGLVersionFlags f)'''
            return QGLFormat.OpenGLVersionFlags()
        def __xor__(self, f):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__xor__(int f)'''
            return QGLFormat.OpenGLVersionFlags()
        def __or__(self, f):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__or__(QGLFormat.OpenGLVersionFlags f)'''
            return QGLFormat.OpenGLVersionFlags()
        def __or__(self, f):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__or__(int f)'''
            return QGLFormat.OpenGLVersionFlags()
        def __int__(self):
            '''int QGLFormat.OpenGLVersionFlags.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__ixor__(QGLFormat.OpenGLVersionFlags f)'''
            return QGLFormat.OpenGLVersionFlags()
        def __ior__(self, f):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__ior__(QGLFormat.OpenGLVersionFlags f)'''
            return QGLFormat.OpenGLVersionFlags()
        def __iand__(self, mask):
            '''QGLFormat.OpenGLVersionFlags QGLFormat.OpenGLVersionFlags.__iand__(int mask)'''
            return QGLFormat.OpenGLVersionFlags()


class QGLContext():
    """"""
    # Enum QGLContext.BindOption
    NoBindOption = 0
    InvertedYBindOption = 0
    MipmapBindOption = 0
    PremultipliedAlphaBindOption = 0
    LinearFilteringBindOption = 0
    DefaultBindOption = 0

    def __init__(self, format, device):
        '''void QGLContext.__init__(QGLFormat format, QPaintDevice device)'''
    def areSharing(self, context1, context2):
        '''static bool QGLContext.areSharing(QGLContext context1, QGLContext context2)'''
        return bool()
    def generateFontDisplayLists(self, fnt, listBase):
        '''void QGLContext.generateFontDisplayLists(QFont fnt, int listBase)'''
    def setInitialized(self, on):
        '''void QGLContext.setInitialized(bool on)'''
    def initialized(self):
        '''bool QGLContext.initialized()'''
        return bool()
    def setWindowCreated(self, on):
        '''void QGLContext.setWindowCreated(bool on)'''
    def windowCreated(self):
        '''bool QGLContext.windowCreated()'''
        return bool()
    def deviceIsPixmap(self):
        '''bool QGLContext.deviceIsPixmap()'''
        return bool()
    def chooseContext(self, shareContext = None):
        '''bool QGLContext.chooseContext(QGLContext shareContext = None)'''
        return bool()
    def currentContext(self):
        '''static QGLContext QGLContext.currentContext()'''
        return QGLContext()
    def overlayTransparentColor(self):
        '''QColor QGLContext.overlayTransparentColor()'''
        return QColor()
    def device(self):
        '''QPaintDevice QGLContext.device()'''
        return QPaintDevice()
    def getProcAddress(self, proc):
        '''sip.voidptr QGLContext.getProcAddress(QString proc)'''
        return sip.voidptr()
    def textureCacheLimit(self):
        '''static int QGLContext.textureCacheLimit()'''
        return int()
    def setTextureCacheLimit(self, size):
        '''static void QGLContext.setTextureCacheLimit(int size)'''
    def deleteTexture(self, tx_id):
        '''void QGLContext.deleteTexture(int tx_id)'''
    def chooseVisual(self):
        '''sip.voidptr QGLContext.chooseVisual()'''
        return sip.voidptr()
    def drawTexture(self, target, textureId, textureTarget = None):
        '''void QGLContext.drawTexture(QRectF target, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def drawTexture(self, point, textureId, textureTarget = None):
        '''void QGLContext.drawTexture(QPointF point, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def bindTexture(self, image, target = None, format = None):
        '''int QGLContext.bindTexture(QImage image, int target = GL_TEXTURE_2D, int format = GL_RGBA)'''
        return int()
    def bindTexture(self, pixmap, target = None, format = None):
        '''int QGLContext.bindTexture(QPixmap pixmap, int target = GL_TEXTURE_2D, int format = GL_RGBA)'''
        return int()
    def bindTexture(self, fileName):
        '''int QGLContext.bindTexture(QString fileName)'''
        return int()
    def bindTexture(self, image, target, format, options):
        '''int QGLContext.bindTexture(QImage image, int target, int format, QGLContext.BindOptions options)'''
        return int()
    def bindTexture(self, pixmap, target, format, options):
        '''int QGLContext.bindTexture(QPixmap pixmap, int target, int format, QGLContext.BindOptions options)'''
        return int()
    def swapBuffers(self):
        '''void QGLContext.swapBuffers()'''
    def doneCurrent(self):
        '''void QGLContext.doneCurrent()'''
    def makeCurrent(self):
        '''void QGLContext.makeCurrent()'''
    def setFormat(self, format):
        '''void QGLContext.setFormat(QGLFormat format)'''
    def requestedFormat(self):
        '''QGLFormat QGLContext.requestedFormat()'''
        return QGLFormat()
    def format(self):
        '''QGLFormat QGLContext.format()'''
        return QGLFormat()
    def reset(self):
        '''void QGLContext.reset()'''
    def isSharing(self):
        '''bool QGLContext.isSharing()'''
        return bool()
    def isValid(self):
        '''bool QGLContext.isValid()'''
        return bool()
    def create(self, shareContext = None):
        '''bool QGLContext.create(QGLContext shareContext = None)'''
        return bool()
    class BindOptions():
        """"""
        def __init__(self):
            '''QGLContext.BindOptions QGLContext.BindOptions.__init__()'''
            return QGLContext.BindOptions()
        def __init__(self):
            '''int QGLContext.BindOptions.__init__()'''
            return int()
        def __init__(self):
            '''void QGLContext.BindOptions.__init__()'''
        def __bool__(self):
            '''int QGLContext.BindOptions.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QGLContext.BindOptions.__ne__(QGLContext.BindOptions f)'''
            return bool()
        def __eq__(self, f):
            '''bool QGLContext.BindOptions.__eq__(QGLContext.BindOptions f)'''
            return bool()
        def __invert__(self):
            '''QGLContext.BindOptions QGLContext.BindOptions.__invert__()'''
            return QGLContext.BindOptions()
        def __and__(self, mask):
            '''QGLContext.BindOptions QGLContext.BindOptions.__and__(int mask)'''
            return QGLContext.BindOptions()
        def __xor__(self, f):
            '''QGLContext.BindOptions QGLContext.BindOptions.__xor__(QGLContext.BindOptions f)'''
            return QGLContext.BindOptions()
        def __xor__(self, f):
            '''QGLContext.BindOptions QGLContext.BindOptions.__xor__(int f)'''
            return QGLContext.BindOptions()
        def __or__(self, f):
            '''QGLContext.BindOptions QGLContext.BindOptions.__or__(QGLContext.BindOptions f)'''
            return QGLContext.BindOptions()
        def __or__(self, f):
            '''QGLContext.BindOptions QGLContext.BindOptions.__or__(int f)'''
            return QGLContext.BindOptions()
        def __int__(self):
            '''int QGLContext.BindOptions.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QGLContext.BindOptions QGLContext.BindOptions.__ixor__(QGLContext.BindOptions f)'''
            return QGLContext.BindOptions()
        def __ior__(self, f):
            '''QGLContext.BindOptions QGLContext.BindOptions.__ior__(QGLContext.BindOptions f)'''
            return QGLContext.BindOptions()
        def __iand__(self, mask):
            '''QGLContext.BindOptions QGLContext.BindOptions.__iand__(int mask)'''
            return QGLContext.BindOptions()


class QGLWidget(QWidget):
    """"""
    def __init__(self, parent = None, shareWidget = None, flags = 0):
        '''void QGLWidget.__init__(QWidget parent = None, QGLWidget shareWidget = None, Qt.WindowFlags flags = 0)'''
    def __init__(self, context, parent = None, shareWidget = None, flags = 0):
        '''void QGLWidget.__init__(QGLContext context, QWidget parent = None, QGLWidget shareWidget = None, Qt.WindowFlags flags = 0)'''
    def __init__(self, format, parent = None, shareWidget = None, flags = 0):
        '''void QGLWidget.__init__(QGLFormat format, QWidget parent = None, QGLWidget shareWidget = None, Qt.WindowFlags flags = 0)'''
    def fontDisplayListBase(self, font, listBase = 2000):
        '''int QGLWidget.fontDisplayListBase(QFont font, int listBase = 2000)'''
        return int()
    def glDraw(self):
        '''void QGLWidget.glDraw()'''
    def glInit(self):
        '''void QGLWidget.glInit()'''
    def resizeEvent(self):
        '''QResizeEvent QGLWidget.resizeEvent()'''
        return QResizeEvent()
    def paintEvent(self):
        '''QPaintEvent QGLWidget.paintEvent()'''
        return QPaintEvent()
    def autoBufferSwap(self):
        '''bool QGLWidget.autoBufferSwap()'''
        return bool()
    def setAutoBufferSwap(self, on):
        '''void QGLWidget.setAutoBufferSwap(bool on)'''
    def paintOverlayGL(self):
        '''void QGLWidget.paintOverlayGL()'''
    def resizeOverlayGL(self, w, h):
        '''void QGLWidget.resizeOverlayGL(int w, int h)'''
    def initializeOverlayGL(self):
        '''void QGLWidget.initializeOverlayGL()'''
    def paintGL(self):
        '''void QGLWidget.paintGL()'''
    def resizeGL(self, w, h):
        '''void QGLWidget.resizeGL(int w, int h)'''
    def initializeGL(self):
        '''void QGLWidget.initializeGL()'''
    def event(self):
        '''QEvent QGLWidget.event()'''
        return QEvent()
    def updateOverlayGL(self):
        '''void QGLWidget.updateOverlayGL()'''
    def updateGL(self):
        '''void QGLWidget.updateGL()'''
    def deleteTexture(self, tx_id):
        '''void QGLWidget.deleteTexture(int tx_id)'''
    def drawTexture(self, target, textureId, textureTarget = None):
        '''void QGLWidget.drawTexture(QRectF target, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def drawTexture(self, point, textureId, textureTarget = None):
        '''void QGLWidget.drawTexture(QPointF point, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def bindTexture(self, image, target = None, format = None):
        '''int QGLWidget.bindTexture(QImage image, int target = GL_TEXTURE_2D, int format = GL_RGBA)'''
        return int()
    def bindTexture(self, pixmap, target = None, format = None):
        '''int QGLWidget.bindTexture(QPixmap pixmap, int target = GL_TEXTURE_2D, int format = GL_RGBA)'''
        return int()
    def bindTexture(self, fileName):
        '''int QGLWidget.bindTexture(QString fileName)'''
        return int()
    def bindTexture(self, image, target, format, options):
        '''int QGLWidget.bindTexture(QImage image, int target, int format, QGLContext.BindOptions options)'''
        return int()
    def bindTexture(self, pixmap, target, format, options):
        '''int QGLWidget.bindTexture(QPixmap pixmap, int target, int format, QGLContext.BindOptions options)'''
        return int()
    def paintEngine(self):
        '''QPaintEngine QGLWidget.paintEngine()'''
        return QPaintEngine()
    def renderText(self, x, y, str, font = QFont(), listBase = 2000):
        '''void QGLWidget.renderText(int x, int y, QString str, QFont font = QFont(), int listBase = 2000)'''
    def renderText(self, x, y, z, str, font = QFont(), listBase = 2000):
        '''void QGLWidget.renderText(float x, float y, float z, QString str, QFont font = QFont(), int listBase = 2000)'''
    def setColormap(self, map):
        '''void QGLWidget.setColormap(QGLColormap map)'''
    def colormap(self):
        '''QGLColormap QGLWidget.colormap()'''
        return QGLColormap()
    def setMouseTracking(self, enable):
        '''void QGLWidget.setMouseTracking(bool enable)'''
    def convertToGLFormat(self, img):
        '''static QImage QGLWidget.convertToGLFormat(QImage img)'''
        return QImage()
    def overlayContext(self):
        '''QGLContext QGLWidget.overlayContext()'''
        return QGLContext()
    def makeOverlayCurrent(self):
        '''void QGLWidget.makeOverlayCurrent()'''
    def grabFrameBuffer(self, withAlpha = False):
        '''QImage QGLWidget.grabFrameBuffer(bool withAlpha = False)'''
        return QImage()
    def renderPixmap(self, width = 0, height = 0, useContext = False):
        '''QPixmap QGLWidget.renderPixmap(int width = 0, int height = 0, bool useContext = False)'''
        return QPixmap()
    def setContext(self, context, shareContext = None, deleteOldContext = True):
        '''void QGLWidget.setContext(QGLContext context, QGLContext shareContext = None, bool deleteOldContext = True)'''
    def context(self):
        '''QGLContext QGLWidget.context()'''
        return QGLContext()
    def setFormat(self, format):
        '''void QGLWidget.setFormat(QGLFormat format)'''
    def format(self):
        '''QGLFormat QGLWidget.format()'''
        return QGLFormat()
    def swapBuffers(self):
        '''void QGLWidget.swapBuffers()'''
    def doubleBuffer(self):
        '''bool QGLWidget.doubleBuffer()'''
        return bool()
    def doneCurrent(self):
        '''void QGLWidget.doneCurrent()'''
    def makeCurrent(self):
        '''void QGLWidget.makeCurrent()'''
    def isSharing(self):
        '''bool QGLWidget.isSharing()'''
        return bool()
    def isValid(self):
        '''bool QGLWidget.isValid()'''
        return bool()
    def qglClearColor(self, c):
        '''void QGLWidget.qglClearColor(QColor c)'''
    def qglColor(self, c):
        '''void QGLWidget.qglColor(QColor c)'''


class QGLBuffer():
    """"""
    # Enum QGLBuffer.UsagePattern
    StreamDraw = 0
    StreamRead = 0
    StreamCopy = 0
    StaticDraw = 0
    StaticRead = 0
    StaticCopy = 0
    DynamicDraw = 0
    DynamicRead = 0
    DynamicCopy = 0

    # Enum QGLBuffer.Type
    VertexBuffer = 0
    IndexBuffer = 0
    PixelPackBuffer = 0
    PixelUnpackBuffer = 0

    # Enum QGLBuffer.Access
    ReadOnly = 0
    WriteOnly = 0
    ReadWrite = 0

    def __init__(self):
        '''void QGLBuffer.__init__()'''
    def __init__(self, type):
        '''void QGLBuffer.__init__(QGLBuffer.Type type)'''
    def __init__(self, other):
        '''void QGLBuffer.__init__(QGLBuffer other)'''
    def unmap(self):
        '''bool QGLBuffer.unmap()'''
        return bool()
    def map(self, access):
        '''sip.voidptr QGLBuffer.map(QGLBuffer.Access access)'''
        return sip.voidptr()
    def allocate(self, data, count):
        '''void QGLBuffer.allocate(sip.voidptr data, int count)'''
    def allocate(self, count):
        '''void QGLBuffer.allocate(int count)'''
    def write(self, offset, data, count):
        '''void QGLBuffer.write(int offset, sip.voidptr data, int count)'''
    def read(self, offset, data, count):
        '''bool QGLBuffer.read(int offset, sip.voidptr data, int count)'''
        return bool()
    def size(self):
        '''int QGLBuffer.size()'''
        return int()
    def bufferId(self):
        '''int QGLBuffer.bufferId()'''
        return int()
    def release(self):
        '''void QGLBuffer.release()'''
    def release(self, type):
        '''static void QGLBuffer.release(QGLBuffer.Type type)'''
    def bind(self):
        '''bool QGLBuffer.bind()'''
        return bool()
    def destroy(self):
        '''void QGLBuffer.destroy()'''
    def isCreated(self):
        '''bool QGLBuffer.isCreated()'''
        return bool()
    def create(self):
        '''bool QGLBuffer.create()'''
        return bool()
    def setUsagePattern(self, value):
        '''void QGLBuffer.setUsagePattern(QGLBuffer.UsagePattern value)'''
    def usagePattern(self):
        '''QGLBuffer.UsagePattern QGLBuffer.usagePattern()'''
        return QGLBuffer.UsagePattern()
    def type(self):
        '''QGLBuffer.Type QGLBuffer.type()'''
        return QGLBuffer.Type()


class QGLColormap():
    """"""
    def __init__(self):
        '''void QGLColormap.__init__()'''
    def __init__(self):
        '''QGLColormap QGLColormap.__init__()'''
        return QGLColormap()
    def setHandle(self, ahandle):
        '''void QGLColormap.setHandle(int ahandle)'''
    def handle(self):
        '''int QGLColormap.handle()'''
        return int()
    def findNearest(self, color):
        '''int QGLColormap.findNearest(int color)'''
        return int()
    def find(self, color):
        '''int QGLColormap.find(int color)'''
        return int()
    def entryColor(self, idx):
        '''QColor QGLColormap.entryColor(int idx)'''
        return QColor()
    def entryRgb(self, idx):
        '''int QGLColormap.entryRgb(int idx)'''
        return int()
    def setEntry(self, idx, color):
        '''void QGLColormap.setEntry(int idx, int color)'''
    def setEntry(self, idx, color):
        '''void QGLColormap.setEntry(int idx, QColor color)'''
    def setEntries(self, colors, base = 0):
        '''void QGLColormap.setEntries(list-of-int colors, int base = 0)'''
    def size(self):
        '''int QGLColormap.size()'''
        return int()
    def isEmpty(self):
        '''bool QGLColormap.isEmpty()'''
        return bool()
    def detach(self):
        '''void QGLColormap.detach()'''


class QGLFramebufferObject(QPaintDevice):
    """"""
    # Enum QGLFramebufferObject.Attachment
    NoAttachment = 0
    CombinedDepthStencil = 0
    Depth = 0

    def __init__(self, size, target = None):
        '''void QGLFramebufferObject.__init__(QSize size, int target = GL_TEXTURE_2D)'''
    def __init__(self, width, height, target = None):
        '''void QGLFramebufferObject.__init__(int width, int height, int target = GL_TEXTURE_2D)'''
    def __init__(self, size, attachment, target = None, internalFormat = None):
        '''void QGLFramebufferObject.__init__(QSize size, QGLFramebufferObject.Attachment attachment, int target = GL_TEXTURE_2D, int internalFormat = GL_RGBA8)'''
    def __init__(self, width, height, attachment, target = None, internalFormat = None):
        '''void QGLFramebufferObject.__init__(int width, int height, QGLFramebufferObject.Attachment attachment, int target = GL_TEXTURE_2D, int internalFormat = GL_RGBA8)'''
    def __init__(self, size, format):
        '''void QGLFramebufferObject.__init__(QSize size, QGLFramebufferObjectFormat format)'''
    def __init__(self, width, height, format):
        '''void QGLFramebufferObject.__init__(int width, int height, QGLFramebufferObjectFormat format)'''
    def blitFramebuffer(self, target, targetRect, source, sourceRect, buffers = None, filter = None):
        '''static void QGLFramebufferObject.blitFramebuffer(QGLFramebufferObject target, QRect targetRect, QGLFramebufferObject source, QRect sourceRect, int buffers = GL_COLOR_BUFFER_BIT, int filter = GL_NEAREST)'''
    def hasOpenGLFramebufferBlit(self):
        '''static bool QGLFramebufferObject.hasOpenGLFramebufferBlit()'''
        return bool()
    def format(self):
        '''QGLFramebufferObjectFormat QGLFramebufferObject.format()'''
        return QGLFramebufferObjectFormat()
    def metric(self, metric):
        '''int QGLFramebufferObject.metric(QPaintDevice.PaintDeviceMetric metric)'''
        return int()
    def hasOpenGLFramebufferObjects(self):
        '''static bool QGLFramebufferObject.hasOpenGLFramebufferObjects()'''
        return bool()
    def handle(self):
        '''int QGLFramebufferObject.handle()'''
        return int()
    def paintEngine(self):
        '''QPaintEngine QGLFramebufferObject.paintEngine()'''
        return QPaintEngine()
    def toImage(self):
        '''QImage QGLFramebufferObject.toImage()'''
        return QImage()
    def size(self):
        '''QSize QGLFramebufferObject.size()'''
        return QSize()
    def drawTexture(self, target, textureId, textureTarget = None):
        '''void QGLFramebufferObject.drawTexture(QRectF target, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def drawTexture(self, point, textureId, textureTarget = None):
        '''void QGLFramebufferObject.drawTexture(QPointF point, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def texture(self):
        '''int QGLFramebufferObject.texture()'''
        return int()
    def release(self):
        '''bool QGLFramebufferObject.release()'''
        return bool()
    def isBound(self):
        '''bool QGLFramebufferObject.isBound()'''
        return bool()
    def bind(self):
        '''bool QGLFramebufferObject.bind()'''
        return bool()
    def isValid(self):
        '''bool QGLFramebufferObject.isValid()'''
        return bool()
    def attachment(self):
        '''QGLFramebufferObject.Attachment QGLFramebufferObject.attachment()'''
        return QGLFramebufferObject.Attachment()


class QGLFramebufferObjectFormat():
    """"""
    def __init__(self):
        '''void QGLFramebufferObjectFormat.__init__()'''
    def __init__(self, other):
        '''void QGLFramebufferObjectFormat.__init__(QGLFramebufferObjectFormat other)'''
    def mipmap(self):
        '''bool QGLFramebufferObjectFormat.mipmap()'''
        return bool()
    def setMipmap(self, enabled):
        '''void QGLFramebufferObjectFormat.setMipmap(bool enabled)'''
    def __ne__(self, other):
        '''bool QGLFramebufferObjectFormat.__ne__(QGLFramebufferObjectFormat other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGLFramebufferObjectFormat.__eq__(QGLFramebufferObjectFormat other)'''
        return bool()
    def internalTextureFormat(self):
        '''int QGLFramebufferObjectFormat.internalTextureFormat()'''
        return int()
    def setInternalTextureFormat(self, internalTextureFormat):
        '''void QGLFramebufferObjectFormat.setInternalTextureFormat(int internalTextureFormat)'''
    def textureTarget(self):
        '''int QGLFramebufferObjectFormat.textureTarget()'''
        return int()
    def setTextureTarget(self, target):
        '''void QGLFramebufferObjectFormat.setTextureTarget(int target)'''
    def attachment(self):
        '''QGLFramebufferObject.Attachment QGLFramebufferObjectFormat.attachment()'''
        return QGLFramebufferObject.Attachment()
    def setAttachment(self, attachment):
        '''void QGLFramebufferObjectFormat.setAttachment(QGLFramebufferObject.Attachment attachment)'''
    def samples(self):
        '''int QGLFramebufferObjectFormat.samples()'''
        return int()
    def setSamples(self, samples):
        '''void QGLFramebufferObjectFormat.setSamples(int samples)'''


class QGLPixelBuffer(QPaintDevice):
    """"""
    def __init__(self, size, format = None, shareWidget = None):
        '''void QGLPixelBuffer.__init__(QSize size, QGLFormat format = QGLFormat.defaultFormat(), QGLWidget shareWidget = None)'''
    def __init__(self, width, height, format = None, shareWidget = None):
        '''void QGLPixelBuffer.__init__(int width, int height, QGLFormat format = QGLFormat.defaultFormat(), QGLWidget shareWidget = None)'''
    def devType(self):
        '''int QGLPixelBuffer.devType()'''
        return int()
    def metric(self, metric):
        '''int QGLPixelBuffer.metric(QPaintDevice.PaintDeviceMetric metric)'''
        return int()
    def hasOpenGLPbuffers(self):
        '''static bool QGLPixelBuffer.hasOpenGLPbuffers()'''
        return bool()
    def format(self):
        '''QGLFormat QGLPixelBuffer.format()'''
        return QGLFormat()
    def paintEngine(self):
        '''QPaintEngine QGLPixelBuffer.paintEngine()'''
        return QPaintEngine()
    def toImage(self):
        '''QImage QGLPixelBuffer.toImage()'''
        return QImage()
    def handle(self):
        '''int QGLPixelBuffer.handle()'''
        return int()
    def size(self):
        '''QSize QGLPixelBuffer.size()'''
        return QSize()
    def deleteTexture(self, texture_id):
        '''void QGLPixelBuffer.deleteTexture(int texture_id)'''
    def drawTexture(self, target, textureId, textureTarget = None):
        '''void QGLPixelBuffer.drawTexture(QRectF target, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def drawTexture(self, point, textureId, textureTarget = None):
        '''void QGLPixelBuffer.drawTexture(QPointF point, int textureId, int textureTarget = GL_TEXTURE_2D)'''
    def bindTexture(self, image, target = None):
        '''int QGLPixelBuffer.bindTexture(QImage image, int target = GL_TEXTURE_2D)'''
        return int()
    def bindTexture(self, pixmap, target = None):
        '''int QGLPixelBuffer.bindTexture(QPixmap pixmap, int target = GL_TEXTURE_2D)'''
        return int()
    def bindTexture(self, fileName):
        '''int QGLPixelBuffer.bindTexture(QString fileName)'''
        return int()
    def updateDynamicTexture(self, texture_id):
        '''void QGLPixelBuffer.updateDynamicTexture(int texture_id)'''
    def releaseFromDynamicTexture(self):
        '''void QGLPixelBuffer.releaseFromDynamicTexture()'''
    def bindToDynamicTexture(self, texture):
        '''bool QGLPixelBuffer.bindToDynamicTexture(int texture)'''
        return bool()
    def generateDynamicTexture(self):
        '''int QGLPixelBuffer.generateDynamicTexture()'''
        return int()
    def doneCurrent(self):
        '''bool QGLPixelBuffer.doneCurrent()'''
        return bool()
    def makeCurrent(self):
        '''bool QGLPixelBuffer.makeCurrent()'''
        return bool()
    def isValid(self):
        '''bool QGLPixelBuffer.isValid()'''
        return bool()


class QGLShader(QObject):
    """"""
    # Enum QGLShader.ShaderTypeBit
    Vertex = 0
    Fragment = 0
    Geometry = 0

    def __init__(self, type, parent = None):
        '''void QGLShader.__init__(QGLShader.ShaderType type, QObject parent = None)'''
    def __init__(self, type, context, parent = None):
        '''void QGLShader.__init__(QGLShader.ShaderType type, QGLContext context, QObject parent = None)'''
    def hasOpenGLShaders(self, type, context = None):
        '''static bool QGLShader.hasOpenGLShaders(QGLShader.ShaderType type, QGLContext context = None)'''
        return bool()
    def shaderId(self):
        '''int QGLShader.shaderId()'''
        return int()
    def log(self):
        '''QString QGLShader.log()'''
        return QString()
    def isCompiled(self):
        '''bool QGLShader.isCompiled()'''
        return bool()
    def sourceCode(self):
        '''QByteArray QGLShader.sourceCode()'''
        return QByteArray()
    def compileSourceFile(self, fileName):
        '''bool QGLShader.compileSourceFile(QString fileName)'''
        return bool()
    def compileSourceCode(self, source):
        '''bool QGLShader.compileSourceCode(QByteArray source)'''
        return bool()
    def compileSourceCode(self, source):
        '''bool QGLShader.compileSourceCode(QString source)'''
        return bool()
    def shaderType(self):
        '''QGLShader.ShaderType QGLShader.shaderType()'''
        return QGLShader.ShaderType()
    class ShaderType():
        """"""
        def __init__(self):
            '''QGLShader.ShaderType QGLShader.ShaderType.__init__()'''
            return QGLShader.ShaderType()
        def __init__(self):
            '''int QGLShader.ShaderType.__init__()'''
            return int()
        def __init__(self):
            '''void QGLShader.ShaderType.__init__()'''
        def __bool__(self):
            '''int QGLShader.ShaderType.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QGLShader.ShaderType.__ne__(QGLShader.ShaderType f)'''
            return bool()
        def __eq__(self, f):
            '''bool QGLShader.ShaderType.__eq__(QGLShader.ShaderType f)'''
            return bool()
        def __invert__(self):
            '''QGLShader.ShaderType QGLShader.ShaderType.__invert__()'''
            return QGLShader.ShaderType()
        def __and__(self, mask):
            '''QGLShader.ShaderType QGLShader.ShaderType.__and__(int mask)'''
            return QGLShader.ShaderType()
        def __xor__(self, f):
            '''QGLShader.ShaderType QGLShader.ShaderType.__xor__(QGLShader.ShaderType f)'''
            return QGLShader.ShaderType()
        def __xor__(self, f):
            '''QGLShader.ShaderType QGLShader.ShaderType.__xor__(int f)'''
            return QGLShader.ShaderType()
        def __or__(self, f):
            '''QGLShader.ShaderType QGLShader.ShaderType.__or__(QGLShader.ShaderType f)'''
            return QGLShader.ShaderType()
        def __or__(self, f):
            '''QGLShader.ShaderType QGLShader.ShaderType.__or__(int f)'''
            return QGLShader.ShaderType()
        def __int__(self):
            '''int QGLShader.ShaderType.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QGLShader.ShaderType QGLShader.ShaderType.__ixor__(QGLShader.ShaderType f)'''
            return QGLShader.ShaderType()
        def __ior__(self, f):
            '''QGLShader.ShaderType QGLShader.ShaderType.__ior__(QGLShader.ShaderType f)'''
            return QGLShader.ShaderType()
        def __iand__(self, mask):
            '''QGLShader.ShaderType QGLShader.ShaderType.__iand__(int mask)'''
            return QGLShader.ShaderType()


class QGLShaderProgram(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QGLShaderProgram.__init__(QObject parent = None)'''
    def __init__(self, context, parent = None):
        '''void QGLShaderProgram.__init__(QGLContext context, QObject parent = None)'''
    def setAttributeBuffer(self, location, type, offset, tupleSize, stride = 0):
        '''void QGLShaderProgram.setAttributeBuffer(int location, int type, int offset, int tupleSize, int stride = 0)'''
    def setAttributeBuffer(self, name, type, offset, tupleSize, stride = 0):
        '''void QGLShaderProgram.setAttributeBuffer(str name, int type, int offset, int tupleSize, int stride = 0)'''
    def geometryOutputType(self):
        '''int QGLShaderProgram.geometryOutputType()'''
        return int()
    def setGeometryOutputType(self, outputType):
        '''void QGLShaderProgram.setGeometryOutputType(int outputType)'''
    def geometryInputType(self):
        '''int QGLShaderProgram.geometryInputType()'''
        return int()
    def setGeometryInputType(self, inputType):
        '''void QGLShaderProgram.setGeometryInputType(int inputType)'''
    def geometryOutputVertexCount(self):
        '''int QGLShaderProgram.geometryOutputVertexCount()'''
        return int()
    def setGeometryOutputVertexCount(self, count):
        '''void QGLShaderProgram.setGeometryOutputVertexCount(int count)'''
    def hasOpenGLShaderPrograms(self, context = None):
        '''static bool QGLShaderProgram.hasOpenGLShaderPrograms(QGLContext context = None)'''
        return bool()
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, int value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, float value)'''
    def setUniformValue(self, location, x, y):
        '''void QGLShaderProgram.setUniformValue(int location, float x, float y)'''
    def setUniformValue(self, location, x, y, z):
        '''void QGLShaderProgram.setUniformValue(int location, float x, float y, float z)'''
    def setUniformValue(self, location, x, y, z, w):
        '''void QGLShaderProgram.setUniformValue(int location, float x, float y, float z, float w)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QVector2D value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QVector3D value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QVector4D value)'''
    def setUniformValue(self, location, color):
        '''void QGLShaderProgram.setUniformValue(int location, QColor color)'''
    def setUniformValue(self, location, point):
        '''void QGLShaderProgram.setUniformValue(int location, QPoint point)'''
    def setUniformValue(self, location, point):
        '''void QGLShaderProgram.setUniformValue(int location, QPointF point)'''
    def setUniformValue(self, location, size):
        '''void QGLShaderProgram.setUniformValue(int location, QSize size)'''
    def setUniformValue(self, location, size):
        '''void QGLShaderProgram.setUniformValue(int location, QSizeF size)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix2x2 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix2x3 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix2x4 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix3x2 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix3x3 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix3x4 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix4x2 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix4x3 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QMatrix4x4 value)'''
    def setUniformValue(self, location, value):
        '''void QGLShaderProgram.setUniformValue(int location, QTransform value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, int value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, float value)'''
    def setUniformValue(self, name, x, y):
        '''void QGLShaderProgram.setUniformValue(str name, float x, float y)'''
    def setUniformValue(self, name, x, y, z):
        '''void QGLShaderProgram.setUniformValue(str name, float x, float y, float z)'''
    def setUniformValue(self, name, x, y, z, w):
        '''void QGLShaderProgram.setUniformValue(str name, float x, float y, float z, float w)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QVector2D value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QVector3D value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QVector4D value)'''
    def setUniformValue(self, name, color):
        '''void QGLShaderProgram.setUniformValue(str name, QColor color)'''
    def setUniformValue(self, name, point):
        '''void QGLShaderProgram.setUniformValue(str name, QPoint point)'''
    def setUniformValue(self, name, point):
        '''void QGLShaderProgram.setUniformValue(str name, QPointF point)'''
    def setUniformValue(self, name, size):
        '''void QGLShaderProgram.setUniformValue(str name, QSize size)'''
    def setUniformValue(self, name, size):
        '''void QGLShaderProgram.setUniformValue(str name, QSizeF size)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix2x2 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix2x3 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix2x4 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix3x2 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix3x3 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix3x4 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix4x2 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix4x3 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QMatrix4x4 value)'''
    def setUniformValue(self, name, value):
        '''void QGLShaderProgram.setUniformValue(str name, QTransform value)'''
    def setUniformValueArray(self, location, values):
        '''void QGLShaderProgram.setUniformValueArray(int location, sequence values)'''
    def setUniformValueArray(self, name, values):
        '''void QGLShaderProgram.setUniformValueArray(str name, sequence values)'''
    def uniformLocation(self, name):
        '''int QGLShaderProgram.uniformLocation(QByteArray name)'''
        return int()
    def uniformLocation(self, name):
        '''int QGLShaderProgram.uniformLocation(QString name)'''
        return int()
    def disableAttributeArray(self, location):
        '''void QGLShaderProgram.disableAttributeArray(int location)'''
    def disableAttributeArray(self, name):
        '''void QGLShaderProgram.disableAttributeArray(str name)'''
    def enableAttributeArray(self, location):
        '''void QGLShaderProgram.enableAttributeArray(int location)'''
    def enableAttributeArray(self, name):
        '''void QGLShaderProgram.enableAttributeArray(str name)'''
    def setAttributeValue(self, location, value):
        '''void QGLShaderProgram.setAttributeValue(int location, float value)'''
    def setAttributeValue(self, location, x, y):
        '''void QGLShaderProgram.setAttributeValue(int location, float x, float y)'''
    def setAttributeValue(self, location, x, y, z):
        '''void QGLShaderProgram.setAttributeValue(int location, float x, float y, float z)'''
    def setAttributeValue(self, location, x, y, z, w):
        '''void QGLShaderProgram.setAttributeValue(int location, float x, float y, float z, float w)'''
    def setAttributeValue(self, location, value):
        '''void QGLShaderProgram.setAttributeValue(int location, QVector2D value)'''
    def setAttributeValue(self, location, value):
        '''void QGLShaderProgram.setAttributeValue(int location, QVector3D value)'''
    def setAttributeValue(self, location, value):
        '''void QGLShaderProgram.setAttributeValue(int location, QVector4D value)'''
    def setAttributeValue(self, location, value):
        '''void QGLShaderProgram.setAttributeValue(int location, QColor value)'''
    def setAttributeValue(self, name, value):
        '''void QGLShaderProgram.setAttributeValue(str name, float value)'''
    def setAttributeValue(self, name, x, y):
        '''void QGLShaderProgram.setAttributeValue(str name, float x, float y)'''
    def setAttributeValue(self, name, x, y, z):
        '''void QGLShaderProgram.setAttributeValue(str name, float x, float y, float z)'''
    def setAttributeValue(self, name, x, y, z, w):
        '''void QGLShaderProgram.setAttributeValue(str name, float x, float y, float z, float w)'''
    def setAttributeValue(self, name, value):
        '''void QGLShaderProgram.setAttributeValue(str name, QVector2D value)'''
    def setAttributeValue(self, name, value):
        '''void QGLShaderProgram.setAttributeValue(str name, QVector3D value)'''
    def setAttributeValue(self, name, value):
        '''void QGLShaderProgram.setAttributeValue(str name, QVector4D value)'''
    def setAttributeValue(self, name, value):
        '''void QGLShaderProgram.setAttributeValue(str name, QColor value)'''
    def setAttributeArray(self, location, values):
        '''void QGLShaderProgram.setAttributeArray(int location, sequence values)'''
    def setAttributeArray(self, name, values):
        '''void QGLShaderProgram.setAttributeArray(str name, sequence values)'''
    def attributeLocation(self, name):
        '''int QGLShaderProgram.attributeLocation(QByteArray name)'''
        return int()
    def attributeLocation(self, name):
        '''int QGLShaderProgram.attributeLocation(QString name)'''
        return int()
    def bindAttributeLocation(self, name, location):
        '''void QGLShaderProgram.bindAttributeLocation(QByteArray name, int location)'''
    def bindAttributeLocation(self, name, location):
        '''void QGLShaderProgram.bindAttributeLocation(QString name, int location)'''
    def programId(self):
        '''int QGLShaderProgram.programId()'''
        return int()
    def release(self):
        '''void QGLShaderProgram.release()'''
    def bind(self):
        '''bool QGLShaderProgram.bind()'''
        return bool()
    def log(self):
        '''QString QGLShaderProgram.log()'''
        return QString()
    def isLinked(self):
        '''bool QGLShaderProgram.isLinked()'''
        return bool()
    def link(self):
        '''bool QGLShaderProgram.link()'''
        return bool()
    def removeAllShaders(self):
        '''void QGLShaderProgram.removeAllShaders()'''
    def addShaderFromSourceFile(self, type, fileName):
        '''bool QGLShaderProgram.addShaderFromSourceFile(QGLShader.ShaderType type, QString fileName)'''
        return bool()
    def addShaderFromSourceCode(self, type, source):
        '''bool QGLShaderProgram.addShaderFromSourceCode(QGLShader.ShaderType type, QByteArray source)'''
        return bool()
    def addShaderFromSourceCode(self, type, source):
        '''bool QGLShaderProgram.addShaderFromSourceCode(QGLShader.ShaderType type, QString source)'''
        return bool()
    def shaders(self):
        '''list-of-QGLShader QGLShaderProgram.shaders()'''
        return [QGLShader()]
    def removeShader(self, shader):
        '''void QGLShaderProgram.removeShader(QGLShader shader)'''
    def addShader(self, shader):
        '''bool QGLShaderProgram.addShader(QGLShader shader)'''
        return bool()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class KParts():
    """"""
    class PartSelectEvent(KParts.Event):
        """"""
        def __init__(self, selected, part, widget):
            '''void KParts.PartSelectEvent.__init__(bool selected, KParts.Part part, QWidget widget)'''
        def test(self, event):
            '''static bool KParts.PartSelectEvent.test(QEvent event)'''
            return bool()
        def widget(self):
            '''QWidget KParts.PartSelectEvent.widget()'''
            return QWidget()
        def part(self):
            '''KParts.Part KParts.PartSelectEvent.part()'''
            return KParts.Part()
        def selected(self):
            '''bool KParts.PartSelectEvent.selected()'''
            return bool()
    class HtmlExtension(QObject):
        """"""
        def __init__(self, parent):
            '''void KParts.HtmlExtension.__init__(KParts.ReadOnlyPart parent)'''
        def hasSelection(self):
            '''bool KParts.HtmlExtension.hasSelection()'''
            return bool()
        def baseUrl(self):
            '''abstract KUrl KParts.HtmlExtension.baseUrl()'''
            return KUrl()
        def childObject(self, obj):
            '''static KParts.HtmlExtension KParts.HtmlExtension.childObject(QObject obj)'''
            return KParts.HtmlExtension()
    class FileInfoExtension():
        """"""
        class QueryModes():
            """"""
            def __init__(self):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__init__()'''
                return KParts.FileInfoExtension.QueryModes()
            def __init__(self):
                '''int KParts.FileInfoExtension.QueryModes.__init__()'''
                return int()
            def __init__(self):
                '''void KParts.FileInfoExtension.QueryModes.__init__()'''
            def __bool__(self):
                '''int KParts.FileInfoExtension.QueryModes.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KParts.FileInfoExtension.QueryModes.__ne__(KParts.FileInfoExtension.QueryModes f)'''
                return bool()
            def __eq__(self, f):
                '''bool KParts.FileInfoExtension.QueryModes.__eq__(KParts.FileInfoExtension.QueryModes f)'''
                return bool()
            def __invert__(self):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__invert__()'''
                return KParts.FileInfoExtension.QueryModes()
            def __and__(self, mask):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__and__(int mask)'''
                return KParts.FileInfoExtension.QueryModes()
            def __xor__(self, f):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__xor__(KParts.FileInfoExtension.QueryModes f)'''
                return KParts.FileInfoExtension.QueryModes()
            def __xor__(self, f):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__xor__(int f)'''
                return KParts.FileInfoExtension.QueryModes()
            def __or__(self, f):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__or__(KParts.FileInfoExtension.QueryModes f)'''
                return KParts.FileInfoExtension.QueryModes()
            def __or__(self, f):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__or__(int f)'''
                return KParts.FileInfoExtension.QueryModes()
            def __int__(self):
                '''int KParts.FileInfoExtension.QueryModes.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__ixor__(KParts.FileInfoExtension.QueryModes f)'''
                return KParts.FileInfoExtension.QueryModes()
            def __ior__(self, f):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__ior__(KParts.FileInfoExtension.QueryModes f)'''
                return KParts.FileInfoExtension.QueryModes()
            def __iand__(self, mask):
                '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.QueryModes.__iand__(int mask)'''
                return KParts.FileInfoExtension.QueryModes()
    class Plugin():
        """"""
        class PluginInfo():
            """"""
            m_absXMLFileName = None # QString - member
            m_document = None # QDomDocument - member
            m_relXMLFileName = None # QString - member
            def __init__(self):
                '''void KParts.Plugin.PluginInfo.__init__()'''
            def __init__(self):
                '''KParts.Plugin.PluginInfo KParts.Plugin.PluginInfo.__init__()'''
                return KParts.Plugin.PluginInfo()
    class HtmlSettingsInterface():
        """"""
        # Enum KParts.HtmlSettingsInterface.JSWindowFocusPolicy
        JSWindowFocusAllow = 0
        JSWindowFocusIgnore = 0
    
        # Enum KParts.HtmlSettingsInterface.JSWindowResizePolicy
        JSWindowResizeAllow = 0
        JSWindowResizeIgnore = 0
    
        # Enum KParts.HtmlSettingsInterface.JSWindowMovePolicy
        JSWindowMoveAllow = 0
        JSWindowMoveIgnore = 0
    
        # Enum KParts.HtmlSettingsInterface.JSWindowStatusPolicy
        JSWindowStatusAllow = 0
        JSWindowStatusIgnore = 0
    
        # Enum KParts.HtmlSettingsInterface.JSWindowOpenPolicy
        JSWindowOpenAllow = 0
        JSWindowOpenAsk = 0
        JSWindowOpenDeny = 0
        JSWindowOpenSmart = 0
    
        # Enum KParts.HtmlSettingsInterface.JavaScriptAdvice
        JavaScriptDunno = 0
        JavaScriptAccept = 0
        JavaScriptReject = 0
    
        # Enum KParts.HtmlSettingsInterface.HtmlSettingsType
        AutoLoadImages = 0
        DnsPrefetchEnabled = 0
        JavaEnabled = 0
        JavascriptEnabled = 0
        MetaRefreshEnabled = 0
        PluginsEnabled = 0
        PrivateBrowsingEnabled = 0
        OfflineStorageDatabaseEnabled = 0
        OfflineWebApplicationCacheEnabled = 0
        LocalStorageEnabled = 0
        UserDefinedStyleSheetURL = 0
    
        def __init__(self):
            '''void KParts.HtmlSettingsInterface.__init__()'''
        def __init__(self):
            '''KParts.HtmlSettingsInterface KParts.HtmlSettingsInterface.__init__()'''
            return KParts.HtmlSettingsInterface()
        def splitDomainAdvice(self, text, domain, javaAdvice, javaScriptAdvice):
            '''static void KParts.HtmlSettingsInterface.splitDomainAdvice(QString text, QString domain, KParts.HtmlSettingsInterface.JavaScriptAdvice javaAdvice, KParts.HtmlSettingsInterface.JavaScriptAdvice javaScriptAdvice)'''
        def javascriptAdviceToText(self, advice):
            '''static str KParts.HtmlSettingsInterface.javascriptAdviceToText(KParts.HtmlSettingsInterface.JavaScriptAdvice advice)'''
            return str()
        def textToJavascriptAdvice(self, text):
            '''static KParts.HtmlSettingsInterface.JavaScriptAdvice KParts.HtmlSettingsInterface.textToJavascriptAdvice(QString text)'''
            return KParts.HtmlSettingsInterface.JavaScriptAdvice()
        def setHtmlSettingsProperty(self, type, value):
            '''abstract bool KParts.HtmlSettingsInterface.setHtmlSettingsProperty(KParts.HtmlSettingsInterface.HtmlSettingsType type, QVariant value)'''
            return bool()
        def htmlSettingsProperty(self, type):
            '''abstract QVariant KParts.HtmlSettingsInterface.htmlSettingsProperty(KParts.HtmlSettingsInterface.HtmlSettingsType type)'''
            return QVariant()
    class ReadWritePart(KParts.ReadOnlyPart):
        """"""
        def __init__(self, parent = None):
            '''void KParts.ReadWritePart.__init__(QObject parent = None)'''
        def saveToUrl(self):
            '''bool KParts.ReadWritePart.saveToUrl()'''
            return bool()
        def saveFile(self):
            '''abstract bool KParts.ReadWritePart.saveFile()'''
            return bool()
        def waitSaveComplete(self):
            '''bool KParts.ReadWritePart.waitSaveComplete()'''
            return bool()
        def save(self):
            '''bool KParts.ReadWritePart.save()'''
            return bool()
        def setModified(self, modified):
            '''void KParts.ReadWritePart.setModified(bool modified)'''
        def setModified(self):
            '''void KParts.ReadWritePart.setModified()'''
        def saveAs(self, url):
            '''bool KParts.ReadWritePart.saveAs(KUrl url)'''
            return bool()
        def closeUrl(self):
            '''bool KParts.ReadWritePart.closeUrl()'''
            return bool()
        def closeUrl(self, promptToSave):
            '''bool KParts.ReadWritePart.closeUrl(bool promptToSave)'''
            return bool()
        def queryClose(self):
            '''bool KParts.ReadWritePart.queryClose()'''
            return bool()
        def isModified(self):
            '''bool KParts.ReadWritePart.isModified()'''
            return bool()
        def setReadWrite(self, readwrite = True):
            '''void KParts.ReadWritePart.setReadWrite(bool readwrite = True)'''
        def isReadWrite(self):
            '''bool KParts.ReadWritePart.isReadWrite()'''
            return bool()
    class BrowserOpenOrSaveQuestion():
        """"""
        # Enum KParts.BrowserOpenOrSaveQuestion.Result
        Save = 0
        Open = 0
        Embed = 0
        Cancel = 0
    
        # Enum KParts.BrowserOpenOrSaveQuestion.Feature
        BasicFeatures = 0
        ServiceSelection = 0
    
        def __init__(self, parent, url, mimeType):
            '''void KParts.BrowserOpenOrSaveQuestion.__init__(QWidget parent, KUrl url, QString mimeType)'''
        def __init__(self):
            '''KParts.BrowserOpenOrSaveQuestion KParts.BrowserOpenOrSaveQuestion.__init__()'''
            return KParts.BrowserOpenOrSaveQuestion()
        def selectedService(self):
            '''unknown-type KParts.BrowserOpenOrSaveQuestion.selectedService()'''
            return unknown-type()
        def askEmbedOrSave(self, flags = 0):
            '''KParts.BrowserOpenOrSaveQuestion.Result KParts.BrowserOpenOrSaveQuestion.askEmbedOrSave(int flags = 0)'''
            return KParts.BrowserOpenOrSaveQuestion.Result()
        def askOpenOrSave(self):
            '''KParts.BrowserOpenOrSaveQuestion.Result KParts.BrowserOpenOrSaveQuestion.askOpenOrSave()'''
            return KParts.BrowserOpenOrSaveQuestion.Result()
        def setFeatures(self, features):
            '''void KParts.BrowserOpenOrSaveQuestion.setFeatures(KParts.BrowserOpenOrSaveQuestion.Features features)'''
        def setSuggestedFileName(self, suggestedFileName):
            '''void KParts.BrowserOpenOrSaveQuestion.setSuggestedFileName(QString suggestedFileName)'''
    class PartBase(KXMLGUIClient):
        """"""
        # Enum KParts.PartBase.PluginLoadingMode
        DoNotLoadPlugins = 0
        LoadPlugins = 0
        LoadPluginsIfEnabled = 0
    
        def __init__(self):
            '''void KParts.PartBase.__init__()'''
        def setPluginInterfaceVersion(self, version):
            '''void KParts.PartBase.setPluginInterfaceVersion(int version)'''
        def loadPlugins(self, parent, parentGUIClient, componentData):
            '''void KParts.PartBase.loadPlugins(QObject parent, KXMLGUIClient parentGUIClient, KComponentData componentData)'''
        def setComponentData(self, componentData):
            '''void KParts.PartBase.setComponentData(KComponentData componentData)'''
        def setComponentData(self, componentData, loadPlugins):
            '''void KParts.PartBase.setComponentData(KComponentData componentData, bool loadPlugins)'''
        def partObject(self):
            '''QObject KParts.PartBase.partObject()'''
            return QObject()
        def setPartObject(self, object):
            '''void KParts.PartBase.setPartObject(QObject object)'''
    class BrowserInterface(QObject):
        """"""
        def __init__(self, parent):
            '''void KParts.BrowserInterface.__init__(QObject parent)'''
        def callMethod(self, name, argument):
            '''void KParts.BrowserInterface.callMethod(str name, QVariant argument)'''
    class BrowserExtension():
        """"""
        class PopupFlags():
            """"""
            def __init__(self):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__init__()'''
                return KParts.BrowserExtension.PopupFlags()
            def __init__(self):
                '''int KParts.BrowserExtension.PopupFlags.__init__()'''
                return int()
            def __init__(self):
                '''void KParts.BrowserExtension.PopupFlags.__init__()'''
            def __bool__(self):
                '''int KParts.BrowserExtension.PopupFlags.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KParts.BrowserExtension.PopupFlags.__ne__(KParts.BrowserExtension.PopupFlags f)'''
                return bool()
            def __eq__(self, f):
                '''bool KParts.BrowserExtension.PopupFlags.__eq__(KParts.BrowserExtension.PopupFlags f)'''
                return bool()
            def __invert__(self):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__invert__()'''
                return KParts.BrowserExtension.PopupFlags()
            def __and__(self, mask):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__and__(int mask)'''
                return KParts.BrowserExtension.PopupFlags()
            def __xor__(self, f):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__xor__(KParts.BrowserExtension.PopupFlags f)'''
                return KParts.BrowserExtension.PopupFlags()
            def __xor__(self, f):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__xor__(int f)'''
                return KParts.BrowserExtension.PopupFlags()
            def __or__(self, f):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__or__(KParts.BrowserExtension.PopupFlags f)'''
                return KParts.BrowserExtension.PopupFlags()
            def __or__(self, f):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__or__(int f)'''
                return KParts.BrowserExtension.PopupFlags()
            def __int__(self):
                '''int KParts.BrowserExtension.PopupFlags.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__ixor__(KParts.BrowserExtension.PopupFlags f)'''
                return KParts.BrowserExtension.PopupFlags()
            def __ior__(self, f):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__ior__(KParts.BrowserExtension.PopupFlags f)'''
                return KParts.BrowserExtension.PopupFlags()
            def __iand__(self, mask):
                '''KParts.BrowserExtension.PopupFlags KParts.BrowserExtension.PopupFlags.__iand__(int mask)'''
                return KParts.BrowserExtension.PopupFlags()
    class SelectorInterface():
        """"""
        # Enum KParts.SelectorInterface.QueryMethod
        __kdevpythondocumentation_builtin_None = 0
        EntireContent = 0
        SelectedContent = 0
    
        def __init__(self):
            '''void KParts.SelectorInterface.__init__()'''
        def __init__(self):
            '''KParts.SelectorInterface KParts.SelectorInterface.__init__()'''
            return KParts.SelectorInterface()
        def querySelectorAll(self, query, method):
            '''abstract list-of-KParts.SelectorInterface.Element KParts.SelectorInterface.querySelectorAll(QString query, KParts.SelectorInterface.QueryMethod method)'''
            return [KParts.SelectorInterface.Element()]
        def querySelector(self, query, method):
            '''abstract KParts.SelectorInterface.Element KParts.SelectorInterface.querySelector(QString query, KParts.SelectorInterface.QueryMethod method)'''
            return KParts.SelectorInterface.Element()
        def supportedQueryMethods(self):
            '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.supportedQueryMethods()'''
            return KParts.SelectorInterface.QueryMethods()
    class FileInfoExtension(QObject):
        """"""
        # Enum KParts.FileInfoExtension.QueryMode
        __kdevpythondocumentation_builtin_None = 0
        AllItems = 0
        SelectedItems = 0
    
        def __init__(self, parent):
            '''void KParts.FileInfoExtension.__init__(KParts.ReadOnlyPart parent)'''
        def queryFor(self, mode):
            '''abstract KFileItemList KParts.FileInfoExtension.queryFor(KParts.FileInfoExtension.QueryMode mode)'''
            return KFileItemList()
        def supportedQueryModes(self):
            '''KParts.FileInfoExtension.QueryModes KParts.FileInfoExtension.supportedQueryModes()'''
            return KParts.FileInfoExtension.QueryModes()
        def hasSelection(self):
            '''bool KParts.FileInfoExtension.hasSelection()'''
            return bool()
        def childObject(self, obj):
            '''static KParts.FileInfoExtension KParts.FileInfoExtension.childObject(QObject obj)'''
            return KParts.FileInfoExtension()
    class Event(QEvent):
        """"""
        def __init__(self, eventName):
            '''void KParts.Event.__init__(str eventName)'''
        def test(self, event):
            '''static bool KParts.Event.test(QEvent event)'''
            return bool()
        def test(self, event, name):
            '''static bool KParts.Event.test(QEvent event, str name)'''
            return bool()
        def eventName(self):
            '''str KParts.Event.eventName()'''
            return str()
    class MainWindow(KXmlGuiWindow, KParts.PartBase):
        """"""
        def __init__(self, parent = None, f = 0):
            '''void KParts.MainWindow.__init__(QWidget parent = None, Qt.WindowFlags f = 0)'''
        def __init__(self, parent, name = None, f = 0):
            '''void KParts.MainWindow.__init__(QWidget parent, str name = None, Qt.WindowFlags f = 0)'''
        def createShellGUI(self, create = True):
            '''void KParts.MainWindow.createShellGUI(bool create = True)'''
        def saveNewToolbarConfig(self):
            '''void KParts.MainWindow.saveNewToolbarConfig()'''
        def slotSetStatusBarText(self):
            '''QString KParts.MainWindow.slotSetStatusBarText()'''
            return QString()
        def createGUI(self, part):
            '''void KParts.MainWindow.createGUI(KParts.Part part)'''
        def configureToolbars(self):
            '''void KParts.MainWindow.configureToolbars()'''
    class BrowserExtension(QObject):
        """"""
        # Enum KParts.BrowserExtension.PopupFlag
        DefaultPopupItems = 0
        ShowNavigationItems = 0
        ShowUp = 0
        ShowReload = 0
        ShowBookmark = 0
        ShowCreateDirectory = 0
        ShowTextSelectionItems = 0
        NoDeletion = 0
        IsLink = 0
        ShowUrlOperations = 0
        ShowProperties = 0
    
        def __init__(self, parent):
            '''void KParts.BrowserExtension.__init__(KParts.ReadOnlyPart parent)'''
        def itemsRemoved(self, items):
            '''void KParts.BrowserExtension.itemsRemoved(KFileItemList items)'''
        def setPageSecurity(self):
            '''int KParts.BrowserExtension.setPageSecurity()'''
            return int()
        def requestFocus(self, part):
            '''void KParts.BrowserExtension.requestFocus(KParts.ReadOnlyPart part)'''
        def resizeTopLevelWidget(self, w, h):
            '''void KParts.BrowserExtension.resizeTopLevelWidget(int w, int h)'''
        def moveTopLevelWidget(self, x, y):
            '''void KParts.BrowserExtension.moveTopLevelWidget(int x, int y)'''
        def addWebSideBar(self, url, name):
            '''void KParts.BrowserExtension.addWebSideBar(KUrl url, QString name)'''
        def mouseOverInfo(self, item):
            '''void KParts.BrowserExtension.mouseOverInfo(KFileItem item)'''
        def selectionInfo(self, items):
            '''void KParts.BrowserExtension.selectionInfo(KFileItemList items)'''
        def selectionInfo(self, text):
            '''void KParts.BrowserExtension.selectionInfo(QString text)'''
        def selectionInfo(self, urls):
            '''void KParts.BrowserExtension.selectionInfo(KUrl.List urls)'''
        def infoMessage(self):
            '''QString KParts.BrowserExtension.infoMessage()'''
            return QString()
        def speedProgress(self, bytesPerSecond):
            '''void KParts.BrowserExtension.speedProgress(int bytesPerSecond)'''
        def loadingProgress(self, percent):
            '''void KParts.BrowserExtension.loadingProgress(int percent)'''
        def createNewWindow(self, url, arguments = None, browserArguments = None, windowArgs = None, part = None):
            '''void KParts.BrowserExtension.createNewWindow(KUrl url, KParts.OpenUrlArguments arguments = KParts.OpenUrlArguments(), KParts.BrowserArguments browserArguments = KParts.BrowserArguments(), KParts.WindowArgs windowArgs = KParts.WindowArgs(), KParts.ReadOnlyPart part)'''
        def setIconUrl(self, url):
            '''void KParts.BrowserExtension.setIconUrl(KUrl url)'''
        def setLocationBarUrl(self, url):
            '''void KParts.BrowserExtension.setLocationBarUrl(QString url)'''
        def openUrlNotify(self):
            '''void KParts.BrowserExtension.openUrlNotify()'''
        def openUrlRequestDelayed(self, url, arguments, browserArguments):
            '''void KParts.BrowserExtension.openUrlRequestDelayed(KUrl url, KParts.OpenUrlArguments arguments, KParts.BrowserArguments browserArguments)'''
        def openUrlRequest(self, url, arguments = None, browserArguments = None):
            '''void KParts.BrowserExtension.openUrlRequest(KUrl url, KParts.OpenUrlArguments arguments = KParts.OpenUrlArguments(), KParts.BrowserArguments browserArguments = KParts.BrowserArguments())'''
        def setActionText(self, name, text):
            '''void KParts.BrowserExtension.setActionText(str name, QString text)'''
        def enableAction(self, name, enabled):
            '''void KParts.BrowserExtension.enableAction(str name, bool enabled)'''
        def pasteRequest(self):
            '''void KParts.BrowserExtension.pasteRequest()'''
        def childObject(self, obj):
            '''static KParts.BrowserExtension KParts.BrowserExtension.childObject(QObject obj)'''
            return KParts.BrowserExtension()
        def actionSlotMapPtr(self):
            '''static dict-of-QByteArray-QByteArray KParts.BrowserExtension.actionSlotMapPtr()'''
            return dict-of-QByteArray-QByteArray()
        def actionSlotMap(self):
            '''static dict-of-QByteArray-QByteArray KParts.BrowserExtension.actionSlotMap()'''
            return dict-of-QByteArray-QByteArray()
        def actionText(self, name):
            '''QString KParts.BrowserExtension.actionText(str name)'''
            return QString()
        def isActionEnabled(self, name):
            '''bool KParts.BrowserExtension.isActionEnabled(str name)'''
            return bool()
        def browserInterface(self):
            '''KParts.BrowserInterface KParts.BrowserExtension.browserInterface()'''
            return KParts.BrowserInterface()
        def setBrowserInterface(self, impl):
            '''void KParts.BrowserExtension.setBrowserInterface(KParts.BrowserInterface impl)'''
        def setURLDropHandlingEnabled(self, enable):
            '''void KParts.BrowserExtension.setURLDropHandlingEnabled(bool enable)'''
        def isURLDropHandlingEnabled(self):
            '''bool KParts.BrowserExtension.isURLDropHandlingEnabled()'''
            return bool()
        def restoreState(self, stream):
            '''void KParts.BrowserExtension.restoreState(QDataStream stream)'''
        def saveState(self, stream):
            '''void KParts.BrowserExtension.saveState(QDataStream stream)'''
        def yOffset(self):
            '''int KParts.BrowserExtension.yOffset()'''
            return int()
        def xOffset(self):
            '''int KParts.BrowserExtension.xOffset()'''
            return int()
        def browserArguments(self):
            '''KParts.BrowserArguments KParts.BrowserExtension.browserArguments()'''
            return KParts.BrowserArguments()
        def setBrowserArguments(self, args):
            '''void KParts.BrowserExtension.setBrowserArguments(KParts.BrowserArguments args)'''
    class SelectorInterface():
        """"""
        class QueryMethods():
            """"""
            def __init__(self):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__init__()'''
                return KParts.SelectorInterface.QueryMethods()
            def __init__(self):
                '''int KParts.SelectorInterface.QueryMethods.__init__()'''
                return int()
            def __init__(self):
                '''void KParts.SelectorInterface.QueryMethods.__init__()'''
            def __bool__(self):
                '''int KParts.SelectorInterface.QueryMethods.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KParts.SelectorInterface.QueryMethods.__ne__(KParts.SelectorInterface.QueryMethods f)'''
                return bool()
            def __eq__(self, f):
                '''bool KParts.SelectorInterface.QueryMethods.__eq__(KParts.SelectorInterface.QueryMethods f)'''
                return bool()
            def __invert__(self):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__invert__()'''
                return KParts.SelectorInterface.QueryMethods()
            def __and__(self, mask):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__and__(int mask)'''
                return KParts.SelectorInterface.QueryMethods()
            def __xor__(self, f):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__xor__(KParts.SelectorInterface.QueryMethods f)'''
                return KParts.SelectorInterface.QueryMethods()
            def __xor__(self, f):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__xor__(int f)'''
                return KParts.SelectorInterface.QueryMethods()
            def __or__(self, f):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__or__(KParts.SelectorInterface.QueryMethods f)'''
                return KParts.SelectorInterface.QueryMethods()
            def __or__(self, f):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__or__(int f)'''
                return KParts.SelectorInterface.QueryMethods()
            def __int__(self):
                '''int KParts.SelectorInterface.QueryMethods.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__ixor__(KParts.SelectorInterface.QueryMethods f)'''
                return KParts.SelectorInterface.QueryMethods()
            def __ior__(self, f):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__ior__(KParts.SelectorInterface.QueryMethods f)'''
                return KParts.SelectorInterface.QueryMethods()
            def __iand__(self, mask):
                '''KParts.SelectorInterface.QueryMethods KParts.SelectorInterface.QueryMethods.__iand__(int mask)'''
                return KParts.SelectorInterface.QueryMethods()
    class ScriptableExtension(QObject):
        """"""
        # Enum KParts.ScriptableExtension.ScriptLanguage
        ECMAScript = 0
        EnumLimit = 0
    
        def __init__(self, parent):
            '''void KParts.ScriptableExtension.__init__(QObject parent)'''
        def releaseValue(self, v):
            '''static QVariant KParts.ScriptableExtension.releaseValue(QVariant v)'''
            return QVariant()
        def acquireValue(self, v):
            '''static QVariant KParts.ScriptableExtension.acquireValue(QVariant v)'''
            return QVariant()
        def release(self, objid):
            '''void KParts.ScriptableExtension.release(int objid)'''
        def acquire(self, objid):
            '''void KParts.ScriptableExtension.acquire(int objid)'''
        def isScriptLanguageSupported(self, lang):
            '''bool KParts.ScriptableExtension.isScriptLanguageSupported(KParts.ScriptableExtension.ScriptLanguage lang)'''
            return bool()
        def evaluateScript(self, callerPrincipal, contextObjectId, code, language = None):
            '''QVariant KParts.ScriptableExtension.evaluateScript(KParts.ScriptableExtension callerPrincipal, int contextObjectId, QString code, KParts.ScriptableExtension.ScriptLanguage language = KParts.ScriptableExtension.ECMAScript)'''
            return QVariant()
        def setException(self, callerPrincipal, message):
            '''bool KParts.ScriptableExtension.setException(KParts.ScriptableExtension callerPrincipal, QString message)'''
            return bool()
        def enumerateProperties(self, callerPrincipal, objId, result):
            '''bool KParts.ScriptableExtension.enumerateProperties(KParts.ScriptableExtension callerPrincipal, int objId, QStringList result)'''
            return bool()
        def removeProperty(self, callerPrincipal, objId, propName):
            '''bool KParts.ScriptableExtension.removeProperty(KParts.ScriptableExtension callerPrincipal, int objId, QString propName)'''
            return bool()
        def put(self, callerPrincipal, objId, propName, value):
            '''bool KParts.ScriptableExtension.put(KParts.ScriptableExtension callerPrincipal, int objId, QString propName, QVariant value)'''
            return bool()
        def get(self, callerPrincipal, objId, propName):
            '''QVariant KParts.ScriptableExtension.get(KParts.ScriptableExtension callerPrincipal, int objId, QString propName)'''
            return QVariant()
        def hasProperty(self, callerPrincipal, objId, propName):
            '''bool KParts.ScriptableExtension.hasProperty(KParts.ScriptableExtension callerPrincipal, int objId, QString propName)'''
            return bool()
        def callAsConstructor(self, callerPrincipal, objId, args):
            '''QVariant KParts.ScriptableExtension.callAsConstructor(KParts.ScriptableExtension callerPrincipal, int objId, list-of-QVariant args)'''
            return QVariant()
        def callFunctionReference(self, callerPrincipal, objId, f, args):
            '''QVariant KParts.ScriptableExtension.callFunctionReference(KParts.ScriptableExtension callerPrincipal, int objId, QString f, list-of-QVariant args)'''
            return QVariant()
        def callAsFunction(self, callerPrincipal, objId, args):
            '''QVariant KParts.ScriptableExtension.callAsFunction(KParts.ScriptableExtension callerPrincipal, int objId, list-of-QVariant args)'''
            return QVariant()
        def enclosingObject(self):
            '''QVariant KParts.ScriptableExtension.enclosingObject()'''
            return QVariant()
        def rootObject(self):
            '''QVariant KParts.ScriptableExtension.rootObject()'''
            return QVariant()
        def host(self):
            '''KParts.ScriptableExtension KParts.ScriptableExtension.host()'''
            return KParts.ScriptableExtension()
        def setHost(self, host):
            '''void KParts.ScriptableExtension.setHost(KParts.ScriptableExtension host)'''
        def adapterFromLiveConnect(self, parentObj, oldApi):
            '''static KParts.ScriptableExtension KParts.ScriptableExtension.adapterFromLiveConnect(QObject parentObj, KParts.LiveConnectExtension oldApi)'''
            return KParts.ScriptableExtension()
        def childObject(self, obj):
            '''static KParts.ScriptableExtension KParts.ScriptableExtension.childObject(QObject obj)'''
            return KParts.ScriptableExtension()
    class BrowserOpenOrSaveQuestion():
        """"""
        class Features():
            """"""
            def __init__(self):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__init__()'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __init__(self):
                '''int KParts.BrowserOpenOrSaveQuestion.Features.__init__()'''
                return int()
            def __init__(self):
                '''void KParts.BrowserOpenOrSaveQuestion.Features.__init__()'''
            def __bool__(self):
                '''int KParts.BrowserOpenOrSaveQuestion.Features.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KParts.BrowserOpenOrSaveQuestion.Features.__ne__(KParts.BrowserOpenOrSaveQuestion.Features f)'''
                return bool()
            def __eq__(self, f):
                '''bool KParts.BrowserOpenOrSaveQuestion.Features.__eq__(KParts.BrowserOpenOrSaveQuestion.Features f)'''
                return bool()
            def __invert__(self):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__invert__()'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __and__(self, mask):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__and__(int mask)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __xor__(self, f):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__xor__(KParts.BrowserOpenOrSaveQuestion.Features f)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __xor__(self, f):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__xor__(int f)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __or__(self, f):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__or__(KParts.BrowserOpenOrSaveQuestion.Features f)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __or__(self, f):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__or__(int f)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __int__(self):
                '''int KParts.BrowserOpenOrSaveQuestion.Features.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__ixor__(KParts.BrowserOpenOrSaveQuestion.Features f)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __ior__(self, f):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__ior__(KParts.BrowserOpenOrSaveQuestion.Features f)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
            def __iand__(self, mask):
                '''KParts.BrowserOpenOrSaveQuestion.Features KParts.BrowserOpenOrSaveQuestion.Features.__iand__(int mask)'''
                return KParts.BrowserOpenOrSaveQuestion.Features()
    class GUIActivateEvent(KParts.Event):
        """"""
        def __init__(self, activated):
            '''void KParts.GUIActivateEvent.__init__(bool activated)'''
        def test(self, event):
            '''static bool KParts.GUIActivateEvent.test(QEvent event)'''
            return bool()
        def activated(self):
            '''bool KParts.GUIActivateEvent.activated()'''
            return bool()
    class LiveConnectExtension(QObject):
        """"""
        # Enum KParts.LiveConnectExtension.Type
        TypeVoid = 0
        TypeBool = 0
        TypeFunction = 0
        TypeNumber = 0
        TypeObject = 0
        TypeString = 0
    
        def __init__(self, parent):
            '''void KParts.LiveConnectExtension.__init__(KParts.ReadOnlyPart parent)'''
        def childObject(self, obj):
            '''static KParts.LiveConnectExtension KParts.LiveConnectExtension.childObject(QObject obj)'''
            return KParts.LiveConnectExtension()
        def unregister(self, objid):
            '''void KParts.LiveConnectExtension.unregister(int objid)'''
        def call(self, objid, func, args, type, retobjid, value):
            '''bool KParts.LiveConnectExtension.call(int objid, QString func, QStringList args, KParts.LiveConnectExtension.Type type, int retobjid, QString value)'''
            return bool()
        def put(self, objid, field, value):
            '''bool KParts.LiveConnectExtension.put(int objid, QString field, QString value)'''
            return bool()
        def get(self, objid, field, type, retobjid, value):
            '''bool KParts.LiveConnectExtension.get(int objid, QString field, KParts.LiveConnectExtension.Type type, int retobjid, QString value)'''
            return bool()
    class TextExtension(QObject):
        """"""
        # Enum KParts.TextExtension.Format
        PlainText = 0
        HTML = 0
    
        def __init__(self, parent):
            '''void KParts.TextExtension.__init__(KParts.ReadOnlyPart parent)'''
        selectionChanged = pyqtSignal() # void selectionChanged() - signal
        def findText(self, string, options):
            '''bool KParts.TextExtension.findText(QString string, KFind.SearchOptions options)'''
            return bool()
        def pageText(self, format):
            '''QString KParts.TextExtension.pageText(KParts.TextExtension.Format format)'''
            return QString()
        def currentPage(self):
            '''int KParts.TextExtension.currentPage()'''
            return int()
        def pageCount(self):
            '''int KParts.TextExtension.pageCount()'''
            return int()
        def completeText(self, format):
            '''QString KParts.TextExtension.completeText(KParts.TextExtension.Format format)'''
            return QString()
        def selectedText(self, format):
            '''QString KParts.TextExtension.selectedText(KParts.TextExtension.Format format)'''
            return QString()
        def hasSelection(self):
            '''bool KParts.TextExtension.hasSelection()'''
            return bool()
        def childObject(self, obj):
            '''static KParts.TextExtension KParts.TextExtension.childObject(QObject obj)'''
            return KParts.TextExtension()
    class OpenUrlEvent(KParts.Event):
        """"""
        def __init__(self, part, url, args = None, browserArgs = None):
            '''void KParts.OpenUrlEvent.__init__(KParts.ReadOnlyPart part, KUrl url, KParts.OpenUrlArguments args = KParts.OpenUrlArguments(), KParts.BrowserArguments browserArgs = KParts.BrowserArguments())'''
        def test(self, event):
            '''static bool KParts.OpenUrlEvent.test(QEvent event)'''
            return bool()
        def browserArguments(self):
            '''KParts.BrowserArguments KParts.OpenUrlEvent.browserArguments()'''
            return KParts.BrowserArguments()
        def arguments(self):
            '''KParts.OpenUrlArguments KParts.OpenUrlEvent.arguments()'''
            return KParts.OpenUrlArguments()
        def url(self):
            '''KUrl KParts.OpenUrlEvent.url()'''
            return KUrl()
        def part(self):
            '''KParts.ReadOnlyPart KParts.OpenUrlEvent.part()'''
            return KParts.ReadOnlyPart()
    class Plugin(QObject, KXMLGUIClient):
        """"""
        def __init__(self, parent = None):
            '''void KParts.Plugin.__init__(QObject parent = None)'''
        def setComponentData(self, instance):
            '''void KParts.Plugin.setComponentData(KComponentData instance)'''
        def loadPlugin(self, parent, libname):
            '''static KParts.Plugin KParts.Plugin.loadPlugin(QObject parent, str libname)'''
            return KParts.Plugin()
        def loadPlugin(self, parent, libname):
            '''static KParts.Plugin KParts.Plugin.loadPlugin(QObject parent, QByteArray libname)'''
            return KParts.Plugin()
        def loadPlugin(self, parent, libname):
            '''static KParts.Plugin KParts.Plugin.loadPlugin(QObject parent, QString libname)'''
            return KParts.Plugin()
        def loadPlugin(self, parent, libname, keyword):
            '''static KParts.Plugin KParts.Plugin.loadPlugin(QObject parent, QString libname, QString keyword)'''
            return KParts.Plugin()
        def pluginInfos(self, instance):
            '''static list-of-KParts.Plugin.PluginInfo KParts.Plugin.pluginInfos(KComponentData instance)'''
            return [KParts.Plugin.PluginInfo()]
        def pluginObjects(self, parent):
            '''static list-of-KParts.Plugin KParts.Plugin.pluginObjects(QObject parent)'''
            return [KParts.Plugin()]
        def loadPlugins(self, parent, instance):
            '''static void KParts.Plugin.loadPlugins(QObject parent, KComponentData instance)'''
        def loadPlugins(self, parent, pluginInfos):
            '''static void KParts.Plugin.loadPlugins(QObject parent, list-of-KParts.Plugin.PluginInfo pluginInfos)'''
        def loadPlugins(self, parent, pluginInfos, instance):
            '''static void KParts.Plugin.loadPlugins(QObject parent, list-of-KParts.Plugin.PluginInfo pluginInfos, KComponentData instance)'''
        def loadPlugins(self, parent, parentGUIClient, instance, enableNewPluginsByDefault = True, interfaceVersionRequired = 0):
            '''static void KParts.Plugin.loadPlugins(QObject parent, KXMLGUIClient parentGUIClient, KComponentData instance, bool enableNewPluginsByDefault = True, int interfaceVersionRequired = 0)'''
        def localXMLFile(self):
            '''QString KParts.Plugin.localXMLFile()'''
            return QString()
        def xmlFile(self):
            '''QString KParts.Plugin.xmlFile()'''
            return QString()
    class BrowserRun(KRun):
        """"""
        # Enum KParts.BrowserRun.NonEmbeddableResult
        Handled = 0
        NotHandled = 0
        Delayed = 0
    
        # Enum KParts.BrowserRun.AskEmbedOrSaveFlags
        InlineDisposition = 0
        AttachmentDisposition = 0
    
        # Enum KParts.BrowserRun.AskSaveResult
        Save = 0
        Open = 0
        Cancel = 0
    
        def __init__(self, url, args, browserArgs, part, window, removeReferrer, trustedSource, hideErrorDialog = False):
            '''void KParts.BrowserRun.__init__(KUrl url, KParts.OpenUrlArguments args, KParts.BrowserArguments browserArgs, KParts.ReadOnlyPart part, QWidget window, bool removeReferrer, bool trustedSource, bool hideErrorDialog = False)'''
        def makeErrorUrl(self, error, errorText, initialUrl):
            '''static KUrl KParts.BrowserRun.makeErrorUrl(int error, QString errorText, QString initialUrl)'''
            return KUrl()
        def handleNonEmbeddable(self, mimeType, pSelectedService):
            '''KParts.BrowserRun.NonEmbeddableResult KParts.BrowserRun.handleNonEmbeddable(QString mimeType, unknown-type pSelectedService)'''
            return KParts.BrowserRun.NonEmbeddableResult()
        def saveUrlUsingKIO(self, srcUrl, destUrl, window, metaData):
            '''static void KParts.BrowserRun.saveUrlUsingKIO(KUrl srcUrl, KUrl destUrl, QWidget window, dict-of-QString-QString metaData)'''
        def saveUrl(self, url, suggestedFileName, window, args):
            '''static void KParts.BrowserRun.saveUrl(KUrl url, QString suggestedFileName, QWidget window, KParts.OpenUrlArguments args)'''
        def slotStatResult(self, job):
            '''void KParts.BrowserRun.slotStatResult(KJob job)'''
        def slotCopyToTempFileResult(self, job):
            '''void KParts.BrowserRun.slotCopyToTempFileResult(KJob job)'''
        def slotBrowserMimetype(self, job, type):
            '''void KParts.BrowserRun.slotBrowserMimetype(KIO.Job job, QString type)'''
        def slotBrowserScanFinished(self, job):
            '''void KParts.BrowserRun.slotBrowserScanFinished(KJob job)'''
        def handleError(self, job):
            '''void KParts.BrowserRun.handleError(KJob job)'''
        def init(self):
            '''void KParts.BrowserRun.init()'''
        def scanFile(self):
            '''void KParts.BrowserRun.scanFile()'''
        def isTextExecutable(self, mimeType):
            '''static bool KParts.BrowserRun.isTextExecutable(QString mimeType)'''
            return bool()
        def allowExecution(self, mimeType, url):
            '''static bool KParts.BrowserRun.allowExecution(QString mimeType, KUrl url)'''
            return bool()
        def simpleSave(self, url, suggestedFileName, window = None):
            '''static void KParts.BrowserRun.simpleSave(KUrl url, QString suggestedFileName, QWidget window = None)'''
        def save(self, url, suggestedFileName):
            '''void KParts.BrowserRun.save(KUrl url, QString suggestedFileName)'''
        def askEmbedOrSave(self, url, mimeType, suggestedFileName = QString(), flags = 0):
            '''static KParts.BrowserRun.AskSaveResult KParts.BrowserRun.askEmbedOrSave(KUrl url, QString mimeType, QString suggestedFileName = QString(), int flags = 0)'''
            return KParts.BrowserRun.AskSaveResult()
        def askSave(self, url, offer, mimeType, suggestedFileName = QString()):
            '''static KParts.BrowserRun.AskSaveResult KParts.BrowserRun.askSave(KUrl url, unknown-type offer, QString mimeType, QString suggestedFileName = QString())'''
            return KParts.BrowserRun.AskSaveResult()
        def serverSuggestsSave(self):
            '''bool KParts.BrowserRun.serverSuggestsSave()'''
            return bool()
        def contentDisposition(self):
            '''QString KParts.BrowserRun.contentDisposition()'''
            return QString()
        def hideErrorDialog(self):
            '''bool KParts.BrowserRun.hideErrorDialog()'''
            return bool()
        def url(self):
            '''KUrl KParts.BrowserRun.url()'''
            return KUrl()
        def part(self):
            '''KParts.ReadOnlyPart KParts.BrowserRun.part()'''
            return KParts.ReadOnlyPart()
        def browserArguments(self):
            '''KParts.BrowserArguments KParts.BrowserRun.browserArguments()'''
            return KParts.BrowserArguments()
        def arguments(self):
            '''KParts.OpenUrlArguments KParts.BrowserRun.arguments()'''
            return KParts.OpenUrlArguments()
    class PartManager(QObject):
        """"""
        # Enum KParts.PartManager.Reason
        ReasonLeftClick = 0
        ReasonMidClick = 0
        ReasonRightClick = 0
        NoReason = 0
    
        # Enum KParts.PartManager.SelectionPolicy
        Direct = 0
        TriState = 0
    
        def __init__(self, parent):
            '''void KParts.PartManager.__init__(QWidget parent)'''
        def __init__(self, topLevel, parent):
            '''void KParts.PartManager.__init__(QWidget topLevel, QObject parent)'''
        def slotManagedTopLevelWidgetDestroyed(self):
            '''void KParts.PartManager.slotManagedTopLevelWidgetDestroyed()'''
        def slotWidgetDestroyed(self):
            '''void KParts.PartManager.slotWidgetDestroyed()'''
        def slotObjectDestroyed(self):
            '''void KParts.PartManager.slotObjectDestroyed()'''
        def setActiveComponent(self, instance):
            '''void KParts.PartManager.setActiveComponent(KComponentData instance)'''
        activePartChanged = pyqtSignal() # void activePartChanged(KParts::Part *) - signal
        partRemoved = pyqtSignal() # void partRemoved(KParts::Part *) - signal
        partAdded = pyqtSignal() # void partAdded(KParts::Part *) - signal
        def reason(self):
            '''int KParts.PartManager.reason()'''
            return int()
        def removeManagedTopLevelWidget(self, topLevel):
            '''void KParts.PartManager.removeManagedTopLevelWidget(QWidget topLevel)'''
        def addManagedTopLevelWidget(self, topLevel):
            '''void KParts.PartManager.addManagedTopLevelWidget(QWidget topLevel)'''
        def parts(self):
            '''list-of-KParts.Part KParts.PartManager.parts()'''
            return [KParts.Part()]
        def selectedWidget(self):
            '''QWidget KParts.PartManager.selectedWidget()'''
            return QWidget()
        def selectedPart(self):
            '''KParts.Part KParts.PartManager.selectedPart()'''
            return KParts.Part()
        def setSelectedPart(self, part, widget = None):
            '''void KParts.PartManager.setSelectedPart(KParts.Part part, QWidget widget = None)'''
        def activeWidget(self):
            '''QWidget KParts.PartManager.activeWidget()'''
            return QWidget()
        def activePart(self):
            '''KParts.Part KParts.PartManager.activePart()'''
            return KParts.Part()
        def setActivePart(self, part, widget = None):
            '''void KParts.PartManager.setActivePart(KParts.Part part, QWidget widget = None)'''
        def replacePart(self, oldPart, newPart, setActive = True):
            '''void KParts.PartManager.replacePart(KParts.Part oldPart, KParts.Part newPart, bool setActive = True)'''
        def removePart(self, part):
            '''void KParts.PartManager.removePart(KParts.Part part)'''
        def addPart(self, part, setActive = True):
            '''void KParts.PartManager.addPart(KParts.Part part, bool setActive = True)'''
        def eventFilter(self, obj, ev):
            '''bool KParts.PartManager.eventFilter(QObject obj, QEvent ev)'''
            return bool()
        def activationButtonMask(self):
            '''int KParts.PartManager.activationButtonMask()'''
            return int()
        def setActivationButtonMask(self, buttonMask):
            '''void KParts.PartManager.setActivationButtonMask(int buttonMask)'''
        def ignoreScrollBars(self):
            '''bool KParts.PartManager.ignoreScrollBars()'''
            return bool()
        def setIgnoreScrollBars(self, ignore):
            '''void KParts.PartManager.setIgnoreScrollBars(bool ignore)'''
        def allowNestedParts(self):
            '''bool KParts.PartManager.allowNestedParts()'''
            return bool()
        def setAllowNestedParts(self, allow):
            '''void KParts.PartManager.setAllowNestedParts(bool allow)'''
        def selectionPolicy(self):
            '''KParts.PartManager.SelectionPolicy KParts.PartManager.selectionPolicy()'''
            return KParts.PartManager.SelectionPolicy()
        def setSelectionPolicy(self, policy):
            '''void KParts.PartManager.setSelectionPolicy(KParts.PartManager.SelectionPolicy policy)'''
    class PartActivateEvent(KParts.Event):
        """"""
        def __init__(self, activated, part, widget):
            '''void KParts.PartActivateEvent.__init__(bool activated, KParts.Part part, QWidget widget)'''
        def test(self, event):
            '''static bool KParts.PartActivateEvent.test(QEvent event)'''
            return bool()
        def widget(self):
            '''QWidget KParts.PartActivateEvent.widget()'''
            return QWidget()
        def part(self):
            '''KParts.Part KParts.PartActivateEvent.part()'''
            return KParts.Part()
        def activated(self):
            '''bool KParts.PartActivateEvent.activated()'''
            return bool()
    class ReadOnlyPart(KParts.Part):
        """"""
        def __init__(self, parent = None):
            '''void KParts.ReadOnlyPart.__init__(QObject parent = None)'''
        def setLocalFilePath(self, localFilePath):
            '''void KParts.ReadOnlyPart.setLocalFilePath(QString localFilePath)'''
        def localFilePath(self):
            '''QString KParts.ReadOnlyPart.localFilePath()'''
            return QString()
        def setUrl(self, url):
            '''void KParts.ReadOnlyPart.setUrl(KUrl url)'''
        def setLocalFileTemporary(self, temp):
            '''void KParts.ReadOnlyPart.setLocalFileTemporary(bool temp)'''
        def isLocalFileTemporary(self):
            '''bool KParts.ReadOnlyPart.isLocalFileTemporary()'''
            return bool()
        def guiActivateEvent(self, event):
            '''void KParts.ReadOnlyPart.guiActivateEvent(KParts.GUIActivateEvent event)'''
        def abortLoad(self):
            '''void KParts.ReadOnlyPart.abortLoad()'''
        def openFile(self):
            '''abstract bool KParts.ReadOnlyPart.openFile()'''
            return bool()
        canceled = pyqtSignal() # void canceled(const QStringamp;) - signal
        completed = pyqtSignal() # void completed() - signal
        completed = pyqtSignal() # void completed(bool) - signal
        started = pyqtSignal() # void started(KIO::Job *) - signal
        def closeStream(self):
            '''bool KParts.ReadOnlyPart.closeStream()'''
            return bool()
        def writeStream(self, data):
            '''bool KParts.ReadOnlyPart.writeStream(QByteArray data)'''
            return bool()
        def openStream(self, mimeType, url):
            '''bool KParts.ReadOnlyPart.openStream(QString mimeType, KUrl url)'''
            return bool()
        def arguments(self):
            '''KParts.OpenUrlArguments KParts.ReadOnlyPart.arguments()'''
            return KParts.OpenUrlArguments()
        def setArguments(self, arguments):
            '''void KParts.ReadOnlyPart.setArguments(KParts.OpenUrlArguments arguments)'''
        def browserExtension(self):
            '''KParts.BrowserExtension KParts.ReadOnlyPart.browserExtension()'''
            return KParts.BrowserExtension()
        def closeUrl(self):
            '''bool KParts.ReadOnlyPart.closeUrl()'''
            return bool()
        def url(self):
            '''KUrl KParts.ReadOnlyPart.url()'''
            return KUrl()
        def openUrl(self, url):
            '''bool KParts.ReadOnlyPart.openUrl(KUrl url)'''
            return bool()
        def showProgressInfo(self, show):
            '''void KParts.ReadOnlyPart.showProgressInfo(bool show)'''
        def isProgressInfoEnabled(self):
            '''bool KParts.ReadOnlyPart.isProgressInfoEnabled()'''
            return bool()
        def setProgressInfoEnabled(self, show):
            '''void KParts.ReadOnlyPart.setProgressInfoEnabled(bool show)'''
    class Part(QObject, KParts.PartBase):
        """"""
        def __init__(self, parent = None):
            '''void KParts.Part.__init__(QObject parent = None)'''
        def slotWidgetDestroyed(self):
            '''void KParts.Part.slotWidgetDestroyed()'''
        def loadPlugins(self):
            '''void KParts.Part.loadPlugins()'''
        def hostContainer(self, containerName):
            '''QWidget KParts.Part.hostContainer(QString containerName)'''
            return QWidget()
        def guiActivateEvent(self, event):
            '''void KParts.Part.guiActivateEvent(KParts.GUIActivateEvent event)'''
        def partSelectEvent(self, event):
            '''void KParts.Part.partSelectEvent(KParts.PartSelectEvent event)'''
        def partActivateEvent(self, event):
            '''void KParts.Part.partActivateEvent(KParts.PartActivateEvent event)'''
        def customEvent(self, event):
            '''void KParts.Part.customEvent(QEvent event)'''
        def setWidget(self, widget):
            '''void KParts.Part.setWidget(QWidget widget)'''
        setStatusBarText = pyqtSignal() # void setStatusBarText(const QStringamp;) - signal
        setWindowCaption = pyqtSignal() # void setWindowCaption(const QStringamp;) - signal
        def iconLoader(self):
            '''KIconLoader KParts.Part.iconLoader()'''
            return KIconLoader()
        def isSelectable(self):
            '''bool KParts.Part.isSelectable()'''
            return bool()
        def setSelectable(self, selectable):
            '''void KParts.Part.setSelectable(bool selectable)'''
        def hitTest(self, widget, globalPos):
            '''KParts.Part KParts.Part.hitTest(QWidget widget, QPoint globalPos)'''
            return KParts.Part()
        def setAutoDeletePart(self, autoDeletePart):
            '''void KParts.Part.setAutoDeletePart(bool autoDeletePart)'''
        def setAutoDeleteWidget(self, autoDeleteWidget):
            '''void KParts.Part.setAutoDeleteWidget(bool autoDeleteWidget)'''
        def manager(self):
            '''KParts.PartManager KParts.Part.manager()'''
            return KParts.PartManager()
        def setManager(self, manager):
            '''void KParts.Part.setManager(KParts.PartManager manager)'''
        def widget(self):
            '''QWidget KParts.Part.widget()'''
            return QWidget()
        def embed(self, parentWidget):
            '''void KParts.Part.embed(QWidget parentWidget)'''
    class BrowserHostExtension(QObject):
        """"""
        def __init__(self, parent):
            '''void KParts.BrowserHostExtension.__init__(KParts.ReadOnlyPart parent)'''
        def childObject(self, obj):
            '''static KParts.BrowserHostExtension KParts.BrowserHostExtension.childObject(QObject obj)'''
            return KParts.BrowserHostExtension()
        def openUrlInFrame(self, url, arguments, browserArguments):
            '''bool KParts.BrowserHostExtension.openUrlInFrame(KUrl url, KParts.OpenUrlArguments arguments, KParts.BrowserArguments browserArguments)'''
            return bool()
        def findFrameParent(self, callingPart, frame):
            '''KParts.BrowserHostExtension KParts.BrowserHostExtension.findFrameParent(KParts.ReadOnlyPart callingPart, QString frame)'''
            return KParts.BrowserHostExtension()
        def frames(self):
            '''list-of-KParts.ReadOnlyPart KParts.BrowserHostExtension.frames()'''
            return [KParts.ReadOnlyPart()]
        def frameNames(self):
            '''QStringList KParts.BrowserHostExtension.frameNames()'''
            return QStringList()
    class HistoryProvider(QObject):
        """"""
        def __init__(self, parent = None):
            '''void KParts.HistoryProvider.__init__(QObject parent = None)'''
        def exists(self):
            '''static bool KParts.HistoryProvider.exists()'''
            return bool()
        inserted = pyqtSignal() # void inserted(const QStringamp;) - signal
        updated = pyqtSignal() # void updated(const QStringListamp;) - signal
        cleared = pyqtSignal() # void cleared() - signal
        def clear(self):
            '''void KParts.HistoryProvider.clear()'''
        def remove(self, item):
            '''void KParts.HistoryProvider.remove(QString item)'''
        def insert(self, item):
            '''void KParts.HistoryProvider.insert(QString item)'''
        def contains(self, item):
            '''bool KParts.HistoryProvider.contains(QString item)'''
            return bool()
        def self(self):
            '''static KParts.HistoryProvider KParts.HistoryProvider.self()'''
            return KParts.HistoryProvider()
    class Factory(KPluginFactory):
        """"""
        def __init__(self, parent = None):
            '''void KParts.Factory.__init__(QObject parent = None)'''
        def createPartObject(self, parentWidget = None, parent = None, classname = None, args = QStringList()):
            '''abstract KParts.Part KParts.Factory.createPartObject(QWidget parentWidget = None, QObject parent = None, str classname = KParts::Part, QStringList args = QStringList())'''
            return KParts.Part()
        def partComponentDataFromLibrary(self, libraryName):
            '''static KComponentData KParts.Factory.partComponentDataFromLibrary(QString libraryName)'''
            return KComponentData()
        def partComponentData(self):
            '''KComponentData KParts.Factory.partComponentData()'''
            return KComponentData()
        def createPart(self, parentWidget = None, parent = None, classname = None, args = QStringList()):
            '''KParts.Part KParts.Factory.createPart(QWidget parentWidget = None, QObject parent = None, str classname = KParts::Part, QStringList args = QStringList())'''
            return KParts.Part()
    class StatusBarExtension(QObject):
        """"""
        def __init__(self, parent):
            '''void KParts.StatusBarExtension.__init__(KParts.ReadOnlyPart parent)'''
        def eventFilter(self, watched, ev):
            '''bool KParts.StatusBarExtension.eventFilter(QObject watched, QEvent ev)'''
            return bool()
        def childObject(self, obj):
            '''static KParts.StatusBarExtension KParts.StatusBarExtension.childObject(QObject obj)'''
            return KParts.StatusBarExtension()
        def setStatusBar(self, status):
            '''void KParts.StatusBarExtension.setStatusBar(KStatusBar status)'''
        def statusBar(self):
            '''KStatusBar KParts.StatusBarExtension.statusBar()'''
            return KStatusBar()
        def removeStatusBarItem(self, widget):
            '''void KParts.StatusBarExtension.removeStatusBarItem(QWidget widget)'''
        def addStatusBarItem(self, widget, stretch, permanent):
            '''void KParts.StatusBarExtension.addStatusBarItem(QWidget widget, int stretch, bool permanent)'''
    class BrowserArguments():
        """"""
        docState = None # QStringList - member
        frameName = None # QString - member
        postData = None # QByteArray - member
        softReload = None # bool - member
        trustedSource = None # bool - member
        def __init__(self):
            '''void KParts.BrowserArguments.__init__()'''
        def __init__(self, args):
            '''void KParts.BrowserArguments.__init__(KParts.BrowserArguments args)'''
    class WindowArgs():
        """"""
        def __init__(self):
            '''void KParts.WindowArgs.__init__()'''
        def __init__(self, args):
            '''void KParts.WindowArgs.__init__(KParts.WindowArgs args)'''
        def __init__(self, _geometry, _fullscreen, _menuBarVisible, _toolBarsVisible, _statusBarVisible, _resizable):
            '''void KParts.WindowArgs.__init__(QRect _geometry, bool _fullscreen, bool _menuBarVisible, bool _toolBarsVisible, bool _statusBarVisible, bool _resizable)'''
        def __init__(self, _x, _y, _width, _height, _fullscreen, _menuBarVisible, _toolBarsVisible, _statusBarVisible, _resizable):
            '''void KParts.WindowArgs.__init__(int _x, int _y, int _width, int _height, bool _fullscreen, bool _menuBarVisible, bool _toolBarsVisible, bool _statusBarVisible, bool _resizable)'''
        def scrollBarsVisible(self):
            '''bool KParts.WindowArgs.scrollBarsVisible()'''
            return bool()
        def setScrollBarsVisible(self, visible):
            '''void KParts.WindowArgs.setScrollBarsVisible(bool visible)'''
        def lowerWindow(self):
            '''bool KParts.WindowArgs.lowerWindow()'''
            return bool()
        def setLowerWindow(self, lower):
            '''void KParts.WindowArgs.setLowerWindow(bool lower)'''
        def isResizable(self):
            '''bool KParts.WindowArgs.isResizable()'''
            return bool()
        def setResizable(self, resizable):
            '''void KParts.WindowArgs.setResizable(bool resizable)'''
        def isStatusBarVisible(self):
            '''bool KParts.WindowArgs.isStatusBarVisible()'''
            return bool()
        def setStatusBarVisible(self, visible):
            '''void KParts.WindowArgs.setStatusBarVisible(bool visible)'''
        def toolBarsVisible(self):
            '''bool KParts.WindowArgs.toolBarsVisible()'''
            return bool()
        def setToolBarsVisible(self, visible):
            '''void KParts.WindowArgs.setToolBarsVisible(bool visible)'''
        def isMenuBarVisible(self):
            '''bool KParts.WindowArgs.isMenuBarVisible()'''
            return bool()
        def setMenuBarVisible(self, visible):
            '''void KParts.WindowArgs.setMenuBarVisible(bool visible)'''
        def isFullScreen(self):
            '''bool KParts.WindowArgs.isFullScreen()'''
            return bool()
        def setFullScreen(self, fs):
            '''void KParts.WindowArgs.setFullScreen(bool fs)'''
        def height(self):
            '''int KParts.WindowArgs.height()'''
            return int()
        def setHeight(self, h):
            '''void KParts.WindowArgs.setHeight(int h)'''
        def width(self):
            '''int KParts.WindowArgs.width()'''
            return int()
        def setWidth(self, w):
            '''void KParts.WindowArgs.setWidth(int w)'''
        def y(self):
            '''int KParts.WindowArgs.y()'''
            return int()
        def setY(self, y):
            '''void KParts.WindowArgs.setY(int y)'''
        def x(self):
            '''int KParts.WindowArgs.x()'''
            return int()
        def setX(self, x):
            '''void KParts.WindowArgs.setX(int x)'''
    class OpenUrlArguments():
        """"""
        def __init__(self):
            '''void KParts.OpenUrlArguments.__init__()'''
        def __init__(self, other):
            '''void KParts.OpenUrlArguments.__init__(KParts.OpenUrlArguments other)'''
        def metaData(self):
            '''dict-of-QString-QString KParts.OpenUrlArguments.metaData()'''
            return dict-of-QString-QString()
        def setActionRequestedByUser(self, userRequested):
            '''void KParts.OpenUrlArguments.setActionRequestedByUser(bool userRequested)'''
        def actionRequestedByUser(self):
            '''bool KParts.OpenUrlArguments.actionRequestedByUser()'''
            return bool()
        def setMimeType(self, mime):
            '''void KParts.OpenUrlArguments.setMimeType(QString mime)'''
        def mimeType(self):
            '''QString KParts.OpenUrlArguments.mimeType()'''
            return QString()
        def setYOffset(self, y):
            '''void KParts.OpenUrlArguments.setYOffset(int y)'''
        def yOffset(self):
            '''int KParts.OpenUrlArguments.yOffset()'''
            return int()
        def setXOffset(self, x):
            '''void KParts.OpenUrlArguments.setXOffset(int x)'''
        def xOffset(self):
            '''int KParts.OpenUrlArguments.xOffset()'''
            return int()
        def setReload(self, b):
            '''void KParts.OpenUrlArguments.setReload(bool b)'''
        def reload(self):
            '''bool KParts.OpenUrlArguments.reload()'''
            return bool()
    class SelectorInterface():
        """"""
        class Element():
            """"""
            def __init__(self):
                '''void KParts.SelectorInterface.Element.__init__()'''
            def __init__(self, other):
                '''void KParts.SelectorInterface.Element.__init__(KParts.SelectorInterface.Element other)'''
            def swap(self, other):
                '''void KParts.SelectorInterface.Element.swap(KParts.SelectorInterface.Element other)'''
            def hasAttribute(self, name):
                '''bool KParts.SelectorInterface.Element.hasAttribute(QString name)'''
                return bool()
            def attribute(self, name, defaultValue = QString()):
                '''QString KParts.SelectorInterface.Element.attribute(QString name, QString defaultValue = QString())'''
                return QString()
            def attributeNames(self):
                '''QStringList KParts.SelectorInterface.Element.attributeNames()'''
                return QStringList()
            def setAttribute(self, name, value):
                '''void KParts.SelectorInterface.Element.setAttribute(QString name, QString value)'''
            def tagName(self):
                '''QString KParts.SelectorInterface.Element.tagName()'''
                return QString()
            def setTagName(self, tag):
                '''void KParts.SelectorInterface.Element.setTagName(QString tag)'''
            def isNull(self):
                '''bool KParts.SelectorInterface.Element.isNull()'''
                return bool()


def qSwap(lhs, rhs):
    '''static void qSwap(KParts.SelectorInterface.Element lhs, KParts.SelectorInterface.Element rhs)'''





#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Convert Python objects to streams of bytes and back (with different
constraints).


This module contains functions that can read and write Python values in a binary
format.  The format is specific to Python, but independent of machine
architecture issues (e.g., you can write a Python value to a file on a PC,
transport the file to a Sun, and read it back there).  Details of the format are
undocumented on purpose; it may change between Python versions (although it
rarely does). [#]_

"""
"""
Indicates the format that the module uses. Version 0 is the historical format,
version 1 (added in Python 2.4) shares interned strings and version 2 (added in
Python 2.5) uses a binary format for floating point numbers. The current version
is 2.

"""
version = None
def dump(value,file,version):
	"""
	Write the value on the open file.  The value must be a supported type.  The
	file must be an open file object such as ``sys.stdout`` or returned by
	:func:`open` or :func:`os.popen`.  It must be opened in binary mode (``'wb'``
	or ``'w+b'``).
	
	If the value has (or contains an object that has) an unsupported type, a
	:exc:`ValueError` exception is raised --- but garbage data will also be written
	to the file.  The object will not be properly read back by :func:`load`.
	
	"""
	pass
	
def load(file):
	"""
	Read one value from the open file and return it.  If no valid value is read
	(e.g. because the data has a different Python version's incompatible marshal
	format), raise :exc:`EOFError`, :exc:`ValueError` or :exc:`TypeError`.  The
	file must be an open file object opened in binary mode (``'rb'`` or
	``'r+b'``).
	
	"""
	pass
	
def dumps(value,version):
	"""
	Return the string that would be written to a file by ``dump(value, file)``.  The
	value must be a supported type.  Raise a :exc:`ValueError` exception if value
	has (or contains an object that has) an unsupported type.
	
	"""
	pass
	
def loads(string):
	"""
	Convert the string to a value.  If no valid value is found, raise
	:exc:`EOFError`, :exc:`ValueError` or :exc:`TypeError`.  Extra characters in the
	string are ignored.
	
	
	In addition, the following constants are defined:
	
	"""
	pass
	



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Standard exception classes.


Exceptions should be class objects.   The exceptions are defined in the module
:mod:`exceptions`.  This module never needs to be imported explicitly: the
exceptions are provided in the built-in namespace as well as the
:mod:`exceptions` module.

"""



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
"""
.. *************
Built-in Types
**************

The following sections describe the standard types that are built into the
interpreter.

"""
class set:


	"""frozenset([iterable])
	
	Return a new set or frozenset object whose elements are taken from
	*iterable*.  The elements of a set must be hashable.  To represent sets of
	sets, the inner sets must be :class:`frozenset` objects.  If *iterable* is
	not specified, a new empty set is returned.
	
	Instances of :class:`set` and :class:`frozenset` provide the following
	operations:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def isdisjoint(self, other):
		"""
		Return True if the set has no elements in common with *other*.  Sets are
		disjoint if and only if their intersection is the empty set.
		
		"""
		pass
		
	def issubset(self, other):
		"""set <= other
		
		Test whether every element in the set is in *other*.
		
		"""
		pass
		
	def set"other(self, ():
		"""
		Test whether the set is a true subset of *other*, that is,
		``set <= other and set != other``.
		
		"""
		pass
		
	def issuperset(self, other):
		"""set >= other
		
		Test whether every element in *other* is in the set.
		
		"""
		pass
		
	def set"other(self, ():
		"""
		Test whether the set is a true superset of *other*, that is, ``set >=
		other and set != other``.
		
		"""
		pass
		
	def union(self, other,more):
		"""set | other | more
		
		Return a new set with elements from the set and all others.
		
		"""
		pass
		
	def intersection(self, other,more):
		"""set & other & more
		
		Return a new set with elements common to the set and all others.
		
		"""
		pass
		
	def difference(self, other,more):
		"""set - other - more
		
		Return a new set with elements in the set that are not in the others.
		
		"""
		pass
		
	def symmetric_difference(self, other):
		"""set ^ other
		
		Return a new set with elements in either the set or *other* but not both.
		
		"""
		pass
		
	def copy(self, ):
		"""
		Return a new set with a shallow copy of *s*.
		
		
		Note, the non-operator versions of :meth:`union`, :meth:`intersection`,
		:meth:`difference`, and :meth:`symmetric_difference`, :meth:`issubset`, and
		:meth:`issuperset` methods will accept any iterable as an argument.  In
		contrast, their operator based counterparts require their arguments to be
		sets.  This precludes error-prone constructions like ``set('abc') & 'cbs'``
		in favor of the more readable ``set('abc').intersection('cbs')``.
		
		Both :class:`set` and :class:`frozenset` support set to set comparisons. Two
		sets are equal if and only if every element of each set is contained in the
		other (each is a subset of the other). A set is less than another set if and
		only if the first set is a proper subset of the second set (is a subset, but
		is not equal). A set is greater than another set if and only if the first set
		is a proper superset of the second set (is a superset, but is not equal).
		
		Instances of :class:`set` are compared to instances of :class:`frozenset`
		based on their members.  For example, ``set('abc') == frozenset('abc')``
		returns ``True`` and so does ``set('abc') in set([frozenset('abc')])``.
		
		The subset and equality comparisons do not generalize to a complete ordering
		function.  For example, any two disjoint sets are not equal and are not
		subsets of each other, so *all* of the following return ``False``: ``a<b``,
		``a==b``, or ``a>b``. Accordingly, sets do not implement the :meth:`__cmp__`
		method.
		
		Since sets only define partial ordering (subset relationships), the output of
		the :meth:`list.sort` method is undefined for lists of sets.
		
		Set elements, like dictionary keys, must be :term:`hashable`.
		
		Binary operations that mix :class:`set` instances with :class:`frozenset`
		return the type of the first operand.  For example: ``frozenset('ab') |
		set('bc')`` returns an instance of :class:`frozenset`.
		
		The following table lists operations available for :class:`set` that do not
		apply to immutable instances of :class:`frozenset`:
		
		"""
		pass
		
	def update(self, other,more):
		"""set |= other | more
		
		Update the set, adding elements from all others.
		
		"""
		pass
		
	def intersection_update(self, other,more):
		"""set &= other & more
		
		Update the set, keeping only elements found in it and all others.
		
		"""
		pass
		
	def difference_update(self, other,more):
		"""set -= other | more
		
		Update the set, removing elements found in others.
		
		"""
		pass
		
	def symmetric_difference_update(self, other):
		"""set ^= other
		
		Update the set, keeping only elements found in either set, but not in both.
		
		"""
		pass
		
	def add(self, elem):
		"""
		Add element *elem* to the set.
		
		"""
		pass
		
	def remove(self, elem):
		"""
		Remove element *elem* from the set.  Raises :exc:`KeyError` if *elem* is
		not contained in the set.
		
		"""
		pass
		
	def discard(self, elem):
		"""
		Remove element *elem* from the set if it is present.
		
		"""
		pass
		
	def pop(self, ):
		"""
		Remove and return an arbitrary element from the set.  Raises
		:exc:`KeyError` if the set is empty.
		
		"""
		pass
		
	def clear(self, ):
		"""
		Remove all elements from the set.
		
		
		Note, the non-operator versions of the :meth:`update`,
		:meth:`intersection_update`, :meth:`difference_update`, and
		:meth:`symmetric_difference_update` methods will accept any iterable as an
		argument.
		
		Note, the *elem* argument to the :meth:`__contains__`, :meth:`remove`, and
		:meth:`discard` methods may be a set.  To support searching for an equivalent
		frozenset, the *elem* set is temporarily mutated during the search and then
		restored.  During the search, the *elem* set should not be read or mutated
		since it does not have a meaningful value.
		
		
		"""
		pass
		
	


class dict:


	"""
	Return a new dictionary initialized from an optional positional argument or from
	a set of keyword arguments. If no arguments are given, return a new empty
	dictionary. If the positional argument *arg* is a mapping object, return a
	dictionary mapping the same keys to the same values as does the mapping object.
	Otherwise the positional argument must be a sequence, a container that supports
	iteration, or an iterator object.  The elements of the argument must each also
	be of one of those kinds, and each must in turn contain exactly two objects.
	The first is used as a key in the new dictionary, and the second as the key's
	value.  If a given key is seen more than once, the last value associated with it
	is retained in the new dictionary.
	
	If keyword arguments are given, the keywords themselves with their associated
	values are added as items to the dictionary. If a key is specified both in the
	positional argument and as a keyword argument, the value associated with the
	keyword is retained in the dictionary. For example, these all return a
	dictionary equal to ``{"one": 1, "two": 2}``:
	
	* ``dict(one=1, two=2)``
	* ``dict({'one': 1, 'two': 2})``
	* ``dict(zip(('one', 'two'), (1, 2)))``
	* ``dict([['two', 2], ['one', 1]])``
	
	The first example only works for keys that are valid Python
	identifiers; the others work with any valid keys.
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def clear(self, ):
		"""
		Remove all items from the dictionary.
		
		"""
		pass
		
	def copy(self, ):
		"""
		Return a shallow copy of the dictionary.
		
		"""
		pass
		
	def _fromkeys(self, seq,value):
		"""
		Create a new dictionary with keys from *seq* and values set to *value*.
		
		:func:`fromkeys` is a class method that returns a new dictionary. *value*
		defaults to ``None``.
		
		"""
		pass
		
	def get(self, key,default):
		"""
		Return the value for *key* if *key* is in the dictionary, else *default*.
		If *default* is not given, it defaults to ``None``, so that this method
		never raises a :exc:`KeyError`.
		
		"""
		pass
		
	def has_key(self, key):
		"""
		Test for the presence of *key* in the dictionary.  :meth:`has_key` is
		deprecated in favor of ``key in d``.
		
		"""
		pass
		
	def items(self, ):
		"""
		Return a copy of the dictionary's list of ``(key, value)`` pairs.
		
		"""
		pass
		
	def iteritems(self, ):
		"""
		Return an iterator over the dictionary's ``(key, value)`` pairs.  See the
		note for :meth:`dict.items`.
		
		Using :meth:`iteritems` while adding or deleting entries in the dictionary
		may raise a :exc:`RuntimeError` or fail to iterate over all entries.
		
		"""
		pass
		
	def iterkeys(self, ):
		"""
		Return an iterator over the dictionary's keys.  See the note for
		:meth:`dict.items`.
		
		Using :meth:`iterkeys` while adding or deleting entries in the dictionary
		may raise a :exc:`RuntimeError` or fail to iterate over all entries.
		
		"""
		pass
		
	def itervalues(self, ):
		"""
		Return an iterator over the dictionary's values.  See the note for
		:meth:`dict.items`.
		
		Using :meth:`itervalues` while adding or deleting entries in the
		dictionary may raise a :exc:`RuntimeError` or fail to iterate over all
		entries.
		
		"""
		pass
		
	def keys(self, ):
		"""
		Return a copy of the dictionary's list of keys.  See the note for
		:meth:`dict.items`.
		
		"""
		pass
		
	def pop(self, key,default):
		"""
		If *key* is in the dictionary, remove it and return its value, else return
		*default*.  If *default* is not given and *key* is not in the dictionary,
		a :exc:`KeyError` is raised.
		
		"""
		pass
		
	def popitem(self, ):
		"""
		Remove and return an arbitrary ``(key, value)`` pair from the dictionary.
		
		:func:`popitem` is useful to destructively iterate over a dictionary, as
		often used in set algorithms.  If the dictionary is empty, calling
		:func:`popitem` raises a :exc:`KeyError`.
		
		"""
		pass
		
	def setdefault(self, key,default):
		"""
		If *key* is in the dictionary, return its value.  If not, insert *key*
		with a value of *default* and return *default*.  *default* defaults to
		``None``.
		
		"""
		pass
		
	def update(self, other):
		"""
		Update the dictionary with the key/value pairs from *other*, overwriting
		existing keys.  Return ``None``.
		
		:func:`update` accepts either another dictionary object or an iterable of
		key/value pairs (as tuples or other iterables of length two).  If keyword
		arguments are specified, the dictionary is then updated with those
		key/value pairs: ``d.update(red=1, blue=2)``.
		
		"""
		pass
		
	def values(self, ):
		"""
		Return a copy of the dictionary's list of values.  See the note for
		:meth:`dict.items`.
		
		"""
		pass
		
	def viewitems(self, ):
		"""
		Return a new view of the dictionary's items (``(key, value)`` pairs).  See
		below for documentation of view objects.
		
		"""
		pass
		
	def viewkeys(self, ):
		"""
		Return a new view of the dictionary's keys.  See below for documentation of
		view objects.
		
		"""
		pass
		
	def viewvalues(self, ):
		"""
		Return a new view of the dictionary's values.  See below for documentation of
		view objects.
		
		"""
		pass
		
	


class memoryview:


	"""
	Create a :class:`memoryview` that references *obj*.  *obj* must support the
	buffer protocol.  Built-in objects that support the buffer protocol include
	:class:`str` and :class:`bytearray` (but not :class:`unicode`).
	
	A :class:`memoryview` has the notion of an *element*, which is the
	atomic memory unit handled by the originating object *obj*.  For many
	simple types such as :class:`str` and :class:`bytearray`, an element
	is a single byte, but other third-party types may expose larger elements.
	
	``len(view)`` returns the total number of elements in the memoryview,
	*view*.  The :class:`~memoryview.itemsize` attribute will give you the
	number of bytes in a single element.
	
	A :class:`memoryview` supports slicing to expose its data.  Taking a single
	index will return a single element as a :class:`str` object.  Full
	slicing will result in a subview::
	
	>>> v = memoryview('abcefg')
	>>> v[1]
	'b'
	>>> v[-1]
	'g'
	>>> v[1:4]
	<memory at 0x77ab28>
	>>> v[1:4].tobytes()
	'bce'
	
	If the object the memoryview is over supports changing its data, the
	memoryview supports slice assignment::
	
	>>> data = bytearray('abcefg')
	>>> v = memoryview(data)
	>>> v.readonly
	False
	>>> v[0] = 'z'
	>>> data
	bytearray(b'zbcefg')
	>>> v[1:4] = '123'
	>>> data
	bytearray(b'z123fg')
	>>> v[2] = 'spam'
	Traceback (most recent call last):
	File "<stdin>", line 1, in <module>
	ValueError: cannot modify size of memoryview object
	
	Notice how the size of the memoryview object cannot be changed.
	
	:class:`memoryview` has two methods:
	
	"""
	
	
	def __init__(self, ):
		pass
	
	def tobytes(self, ):
		"""
		Return the data in the buffer as a bytestring (an object of class
		:class:`str`). ::
		
		>>> m = memoryview("abc")
		>>> m.tobytes()
		'abc'
		
		"""
		pass
		
	def tolist(self, ):
		"""
		Return the data in the buffer as a list of integers. ::
		
		>>> memoryview("abc").tolist()
		[97, 98, 99]
		
		There are also several readonly attributes available:
		
		"""
		pass
		
	


